@@ -72,6 +72,8 @@ show_popupmenu( url, slot ); \
 #define POPUPMENU_BOARD2 \
     "<menuitem action='SearchCacheBoard'/>" \
     "<separator/>" \
+    "<menuitem action='ImportDat'/>" \
+    "<separator/>" \
     "<menuitem action='PreferenceBoard'/>" \
     "</popup>" \
 
@@ -89,6 +91,8 @@ show_popupmenu( url, slot ); \
     "<separator/>" \
     "<menuitem action='SearchCacheBoard'/>" \
     "<separator/>" \
+    "<menuitem action='ImportDat'/>" \
+    "<separator/>" \
     "<menuitem action='PreferenceArticle'/>" \
     "<menuitem action='PreferenceBoard'/>" \
     "<menuitem action='PreferenceImage'/>"
@@ -100,7 +104,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
       m_treeview( url, DNDTARGET_FAVORITE, m_columns, true, CONFIG::get_fontname( FONT_BBS ), COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN ),
       m_ready_tree( false ),
       m_jump_y( -1 ),
-      m_search_invert( 0 ),
+      m_search_invert( false ),
       m_open_only_onedir( false ),
       m_cancel_expand( false ),
       m_expanding( 0 ),
@@ -134,6 +138,9 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
 
 #endif
 */
+    // 共有UNDOバッファをセット
+    m_treeview.set_undo_buffer( BBSLIST::get_undo_buffer_favorite() );
+
     // 列の登録
     m_treeview.create_column( CONFIG::get_tree_ypad() );
     m_treeview.set_column_for_height( 0 );
@@ -169,7 +176,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)"), sigc::mem_fun( *this, &BBSListViewBase::open_selected_rows ) );
 
     action_group()->add( Gtk::Action::create( "CheckUpdateRows", "更新チェックのみ(_H)"), sigc::mem_fun( *this, &BBSListViewBase::slot_checkupdate_selected_rows ) );
-    action_group()->add( Gtk::Action::create( "CheckUpdateOpenRows", "更新されたスレをタブで開く(_E)"),
+    action_group()->add( Gtk::Action::create( "CheckUpdateOpenRows", "更新された行をタブで開く(_E)"),
                          sigc::mem_fun( *this, &BBSListViewBase::slot_checkupdate_open_selected_rows ) );
 
     action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_U)"), sigc::mem_fun( *this, &BBSListViewBase::slot_copy_url ) );
@@ -178,12 +185,13 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
 
     action_group()->add( Gtk::Action::create( "CheckUpdate_Menu", "更新チェック(_M)" ) );
     action_group()->add( Gtk::Action::create( "CheckUpdateDir", "更新チェックのみ(_R)"), sigc::mem_fun( *this, &BBSListViewBase::slot_check_update_dir ) );
-    action_group()->add( Gtk::Action::create( "CheckUpdateOpenDir", "更新されたスレをタブで開く(_A)"),
+    action_group()->add( Gtk::Action::create( "CheckUpdateOpenDir", "更新された行をタブで開く(_A)"),
                          sigc::mem_fun( *this, &BBSListViewBase::slot_check_update_open_dir ) );
     action_group()->add( Gtk::Action::create( "CancelCheckUpdate", "キャンセル(_C)" ),
                          sigc::mem_fun( *this, &BBSListViewBase::slot_cancel_check_update ) );
 
     action_group()->add( Gtk::Action::create( "SearchCacheBoard", "キャッシュ内ログ検索(_S)"), sigc::mem_fun( *this, &BBSListViewBase::slot_search_cache_board ) );
+    action_group()->add( Gtk::Action::create( "ImportDat", "datのインポート(_I)"), sigc::mem_fun( *this, &BBSListViewBase::slot_import_dat ) );
 
     action_group()->add( Gtk::Action::create( "PreferenceArticle", "スレのプロパティ(_P)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_article ) );
     action_group()->add( Gtk::Action::create( "PreferenceBoard", "板のプロパティ(_B)..."), sigc::mem_fun( *this, &BBSListViewBase::slot_preferences_board ) );
@@ -394,6 +402,16 @@ void BBSListViewBase::set_editable( const bool editable )
 }
 
 
+//
+// 親ウィンドウをセット
+//
+void BBSListViewBase::set_parent_win( Gtk::Window* parent_win )
+{
+    SKELETON::View::set_parent_win( parent_win );
+    get_treeview().set_parent_win( parent_win );
+}
+
+
 //
 // コマンド
 //
@@ -403,7 +421,8 @@ const bool BBSListViewBase::set_command( const std::string& command, const std::
     else if( command == "remove_item" ) remove_item( arg1 );
     else if( command == "edit_tree" ) edit_tree();
     else if( command == "save_xml" ) save_xml( false );
-    else if( command == "toggle_icon" ) toggle_icon( arg1 );
+    else if( command == "toggle_articleicon" ) toggle_articleicon( arg1 );
+    else if( command == "toggle_boardicon" ) toggle_boardicon( arg1 );
     else if( command == "replace_thread" ) replace_thread( arg1, arg2 );
 
     else if( command == "check_update_root" ) check_update_root( false );
@@ -536,7 +555,7 @@ void BBSListViewBase::close_view()
 //
 void BBSListViewBase::delete_view()
 {
-    SKELETON::MsgDiag mdiag( NULL, "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    SKELETON::MsgDiag mdiag( get_parent_win(), "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
     if( mdiag.run() != Gtk::RESPONSE_YES ) return;
 
     delete_view_impl();
@@ -666,7 +685,6 @@ const bool BBSListViewBase::operate_view( const int control )
             CORE::core_set_command( "toggle_article" );
             break;
 
-
         case CONTROL::TabLeft:
             BBSLIST::get_admin()->set_command( "tab_left" );
             break;
@@ -675,6 +693,44 @@ const bool BBSListViewBase::operate_view( const int control )
             BBSLIST::get_admin()->set_command( "tab_right" );
             break;
 
+        // タブ位置(1-9)で移動
+        case CONTROL::TabNum1:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "1" );
+            break;
+
+        case CONTROL::TabNum2:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "2" );
+            break;
+
+        case CONTROL::TabNum3:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "3" );
+            break;
+
+        case CONTROL::TabNum4:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "4" );
+            break;
+
+        case CONTROL::TabNum5:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "5" );
+            break;
+
+        case CONTROL::TabNum6:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "6" );
+            break;
+
+        case CONTROL::TabNum7:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "7" );
+            break;
+
+        case CONTROL::TabNum8:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "8" );
+            break;
+
+        case CONTROL::TabNum9:
+            BBSLIST::get_admin()->set_command( "tab_num", "", "9" );
+            break;
+
+        // 終了
         case CONTROL::Quit:
             close_view();
             break;
@@ -699,12 +755,12 @@ const bool BBSListViewBase::operate_view( const int control )
 
         // 検索
         case CONTROL::Search:
-            m_search_invert = false;
+            set_search_invert( false );
             BBSLIST::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
         case CONTROL::SearchInvert:
-            m_search_invert = true;
+            set_search_invert( true );
             BBSLIST::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
@@ -739,6 +795,14 @@ const bool BBSListViewBase::operate_view( const int control )
             CORE::core_set_command( "cancel_check_update" );
             break;
 
+        case CONTROL::Undo:
+            undo();
+            break;
+
+        case CONTROL::Redo:
+            redo();
+            break;
+
         default:
             return false;
     }
@@ -755,14 +819,16 @@ const bool BBSListViewBase::operate_view( const int control )
 //
 void BBSListViewBase::activate_act_before_popupmenu( const std::string& url )
 {
-    Glib::RefPtr< Gtk::Action > act_search, act_board, act_article, act_image, act_opentab;
+    Glib::RefPtr< Gtk::Action > act_search, act_import, act_board, act_article, act_image, act_opentab;
     act_search = action_group()->get_action( "SearchCacheBoard" );
+    act_import = action_group()->get_action( "ImportDat" );
     act_board = action_group()->get_action( "PreferenceBoard" );
     act_article = action_group()->get_action( "PreferenceArticle" );
     act_image = action_group()->get_action( "PreferenceImage" );
     act_opentab = action_group()->get_action( "OpenTab" );
 
     if( act_search ) act_search->set_sensitive( false );
+    if( act_import ) act_import->set_sensitive( false );
     if( act_board ) act_board->set_sensitive( false );
     if( act_article ) act_article->set_sensitive( false );
     if( act_image ) act_image->set_sensitive( false );
@@ -772,7 +838,9 @@ void BBSListViewBase::activate_act_before_popupmenu( const std::string& url )
     switch( type ){
 
         case TYPE_BOARD:
+        case TYPE_BOARD_UPDATE:
             if( act_search ) act_search->set_sensitive( true );
+            if( act_import ) act_import->set_sensitive( true );
             if( act_board ) act_board->set_sensitive( true );
             break;
 
@@ -903,7 +971,8 @@ bool BBSListViewBase::slot_button_press( GdkEventButton* event )
     m_dblclick = false;
     if( event->type == GDK_2BUTTON_PRESS ) m_dblclick = true; 
 
-    BBSLIST::get_admin()->set_command( "switch_admin" );
+    // 親ウィンドウがメインウィンドウならフォーカスを移す
+    if( ! get_parent_win() ) BBSLIST::get_admin()->set_command( "switch_admin" );
 
     return true;
 }
@@ -1133,7 +1202,8 @@ void BBSListViewBase::slot_open_browser()
 void BBSListViewBase::slot_append_favorite()
 {
     CORE::DATA_INFO_LIST list_info;
-    m_treeview.get_info_in_selection( list_info );
+    const bool dir = true;
+    m_treeview.get_info_in_selection( list_info, dir );
 
     if( list_info.size() ){
 
@@ -1242,7 +1312,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
         if( ! id.empty() && ! passwd.empty() ) basicauth = id + ":" + passwd; 
 
         if( name.empty() || url.empty() ){
-            SKELETON::MsgDiag mdiag( NULL, "板名またはアドレスが空白です", false, Gtk::MESSAGE_ERROR );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "板名またはアドレスが空白です", false, Gtk::MESSAGE_ERROR );
             mdiag.run();
             mdiag.hide();
             add_newetcboard( move, url_org, name, id, passwd );
@@ -1264,7 +1334,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
 
         // boardid 取得
         if( ! regex.exec( "(http://.*)/([^/]*)/$" , url ) ){
-            SKELETON::MsgDiag mdiag( NULL, "アドレスが不正な形式になっています", false, Gtk::MESSAGE_ERROR );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "アドレスが不正な形式になっています", false, Gtk::MESSAGE_ERROR );
             mdiag.run();
             mdiag.hide();
             add_newetcboard( move, url_org, name, id, passwd );
@@ -1282,7 +1352,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
         std::string boardid = regex.str( 2 );
 
         if( boardid.empty() ){
-            SKELETON::MsgDiag mdiag( NULL, "板IDを取得出来ません", false, Gtk::MESSAGE_ERROR );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "板IDを取得出来ません", false, Gtk::MESSAGE_ERROR );
             mdiag.run();
             mdiag.hide();
             add_newetcboard( move, url_org, name, id, passwd );
@@ -1295,7 +1365,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
 
         // 既に登録されているか確認
         if( ! move && ! DBTREE::board_name( url ).empty() ){
-            SKELETON::MsgDiag mdiag( NULL, name + "\n" + url + "\n\nは既に登録されています", false, Gtk::MESSAGE_ERROR );
+            SKELETON::MsgDiag mdiag( get_parent_win(), name + "\n" + url + "\n\nは既に登録されています", false, Gtk::MESSAGE_ERROR );
             mdiag.run();
             mdiag.hide();
             add_newetcboard( move, url_org, name,  id, passwd );
@@ -1336,7 +1406,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
 
         else{
 
-            SKELETON::MsgDiag mdiag( NULL, "外部板の登録に失敗しました。アドレスを確認してください", false, Gtk::MESSAGE_ERROR );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "外部板の登録に失敗しました。アドレスを確認してください", false, Gtk::MESSAGE_ERROR );
             mdiag.run();
             mdiag.hide();
             add_newetcboard( move, url_org, name, id, passwd );
@@ -1430,7 +1500,7 @@ void BBSListViewBase::slot_select_all_dir()
 //
 void BBSListViewBase::slot_select_all()
 {
-    SKELETON::MsgDiag mdiag( NULL, "全ての行を選択しますか？\n\n(注意) ディレクトリは全て展開されます。", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    SKELETON::MsgDiag mdiag( get_parent_win(), "全ての行を選択しますか？\n\n(注意) ディレクトリは全て展開されます。", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
     mdiag.set_default_response( Gtk::RESPONSE_NO );
     if( mdiag.run() != Gtk::RESPONSE_YES ) return;
 
@@ -1453,7 +1523,7 @@ void BBSListViewBase::slot_select_all()
 //
 // 呼び出した後に CORE::get_checkupdate_manager()->run() を実行すること
 //
-void BBSListViewBase::check_update_dir( Gtk::TreeModel::Path path )
+void BBSListViewBase::check_update_dir( Gtk::TreeModel::Path path, const bool open )
 {
     if( path.empty() ) return;
 
@@ -1470,8 +1540,10 @@ void BBSListViewBase::check_update_dir( Gtk::TreeModel::Path path )
             int type = path2type( path );
             std::string url = path2url( path );
 
-            if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ) );
-            else if( type == TYPE_DIR ) check_update_dir( path );
+            if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ), open );
+            else if( CONFIG::get_check_update_board() && ( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ) )
+                CORE::get_checkupdate_manager()->push_back( DBTREE::url_subject( url ), open );
+            else if( type == TYPE_DIR ) check_update_dir( path, open );
 
             path.next();
         }
@@ -1489,7 +1561,7 @@ void BBSListViewBase::slot_check_update_dir()
     if( m_path_selected.empty() ) return;
 
     if( ! SESSION::is_online() ){
-        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
         mdiag.run();
         return;
     }
@@ -1498,15 +1570,15 @@ void BBSListViewBase::slot_check_update_dir()
     std::cout << "BBSListViewBase::slot_check_check_update_dir path = " << m_path_selected.to_string() << std::endl;
 #endif
 
-    check_update_dir( m_path_selected );
-    CORE::get_checkupdate_manager()->run( false );
+    check_update_dir( m_path_selected, false );
+    CORE::get_checkupdate_manager()->run();
 }
 
 // 全更新チェックして開く
 void BBSListViewBase::slot_check_update_open_dir()
 {
     if( ! SESSION::is_online() ){
-        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
         mdiag.run();
         return;
     }
@@ -1517,8 +1589,8 @@ void BBSListViewBase::slot_check_update_open_dir()
     std::cout << "BBSListViewBase::slot_check_check_update_open_dir path = " << m_path_selected.to_string() << std::endl;
 #endif
 
-    check_update_dir( m_path_selected );
-    CORE::get_checkupdate_manager()->run( true );
+    check_update_dir( m_path_selected, true );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -1527,7 +1599,7 @@ void BBSListViewBase::slot_check_update_open_dir()
 //
 // 呼び出した後に CORE::get_checkupdate_manager()->run() を実行すること
 //
-void BBSListViewBase::check_update_root( const Gtk::TreeModel::Children& children )
+void BBSListViewBase::check_update_root( const Gtk::TreeModel::Children& children, const bool open )
 {
     Gtk::TreeModel::iterator it = children.begin();
     while( it != children.end() )
@@ -1537,8 +1609,10 @@ void BBSListViewBase::check_update_root( const Gtk::TreeModel::Children& childre
         const int type = row2type( row );
         const std::string url = row2url( row );
 
-        if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ) );
-        else if( type == TYPE_DIR ) check_update_root( row.children() );
+        if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ), open );
+        else if( CONFIG::get_check_update_board() && ( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ) )
+            CORE::get_checkupdate_manager()->push_back( DBTREE::url_subject( url ), open );
+        else if( type == TYPE_DIR ) check_update_root( row.children(), open );
 
         ++it;
     }
@@ -1550,11 +1624,11 @@ void BBSListViewBase::check_update_root( const Gtk::TreeModel::Children& childre
 //
 // tab_open はタブで開くか否か
 //
-void BBSListViewBase::check_update_root( const bool tab_open )
+void BBSListViewBase::check_update_root( const bool open )
 {
-    check_update_root( m_treestore->children() );
+    check_update_root( m_treestore->children(), open );
 
-    CORE::get_checkupdate_manager()->run( tab_open );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -1579,6 +1653,18 @@ void BBSListViewBase::slot_search_cache_board()
 }
 
 
+//
+// datのインポート
+//
+void BBSListViewBase::slot_import_dat()
+{
+    if( m_path_selected.empty() ) return;
+    std::string url = path2url( m_path_selected );
+
+    CORE::core_set_command( "import_dat", url, "show_diag" );
+}
+
+
 //
 // 板プロパティ表示
 //
@@ -1587,7 +1673,7 @@ void BBSListViewBase::slot_preferences_board()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARD, DBTREE::url_subject( url ) );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD, DBTREE::url_subject( url ) );
     pref->run();
     delete pref;
 }
@@ -1602,7 +1688,7 @@ void BBSListViewBase::slot_preferences_article()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_ARTICLE, DBTREE::url_dat( url ) );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_ARTICLE, DBTREE::url_dat( url ) );
     pref->run();
     delete pref;
 }
@@ -1616,7 +1702,7 @@ void BBSListViewBase::slot_preferences_image()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_IMAGE, url );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_IMAGE, url );
     pref->run();
     delete pref;
 }
@@ -1668,6 +1754,8 @@ const bool BBSListViewBase::open_row( Gtk::TreePath& path, const bool tab )
     std::string str_tab = "false";
     if( tab ) str_tab = "true";
 
+    const std::string str_mode = "";
+
     Glib::ustring url = path2url( path );
     int type = path2type( path );
 
@@ -1676,20 +1764,21 @@ const bool BBSListViewBase::open_row( Gtk::TreePath& path, const bool tab )
     switch( type ){
 
         case TYPE_BOARD:
-            CORE::core_set_command( "open_board", DBTREE::url_subject( url ), str_tab, "" );
+        case TYPE_BOARD_UPDATE:
+            CORE::core_set_command( "open_board", DBTREE::url_subject( url ), str_tab, str_mode );
             break;
 
         case TYPE_THREAD_OLD:
-            toggle_icon( url ); // break;しない
+            toggle_articleicon( url ); // break;しない
         case TYPE_THREAD:
         case TYPE_THREAD_UPDATE:
-            CORE::core_set_command( "open_article", DBTREE::url_dat( url ), str_tab, "" );
+            CORE::core_set_command( "open_article", DBTREE::url_dat( url ), str_tab, str_mode );
             break;
 
         case TYPE_IMAGE:
 
             if( DBIMG::get_abone( url )){
-                SKELETON::MsgDiag mdiag( NULL, "あぼ〜んされています" );
+                SKELETON::MsgDiag mdiag( get_parent_win(), "あぼ〜んされています" );
                 mdiag.run();
             }
             else{
@@ -1754,6 +1843,7 @@ void BBSListViewBase::open_selected_rows()
         switch( type ){
 
             case TYPE_BOARD:
+            case TYPE_BOARD_UPDATE:
                 url = DBTREE::url_subject( url );
                 if( !list_url_board.empty() ) list_url_board += " ";
                 list_url_board += url;
@@ -1780,7 +1870,7 @@ void BBSListViewBase::open_selected_rows()
 //
 // このあとで CORE::get_checkupdate_manager()->run() を実行すること
 //
-void BBSListViewBase::checkupdate_selected_rows()
+void BBSListViewBase::checkupdate_selected_rows( const bool open )
 {
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
     std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
@@ -1792,22 +1882,24 @@ void BBSListViewBase::checkupdate_selected_rows()
         int type = path2type( path );
         std::string url = path2url( path );
 
-        if( type == TYPE_THREAD || TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ) );            
+        if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ), open );
+        else if( CONFIG::get_check_update_board() && ( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ) )
+            CORE::get_checkupdate_manager()->push_back( DBTREE::url_subject( url ), open );
     }
 }
 
 
 void BBSListViewBase::slot_checkupdate_selected_rows()
 {
-    checkupdate_selected_rows();
-    CORE::get_checkupdate_manager()->run( false );
+    checkupdate_selected_rows( false );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
 void BBSListViewBase::slot_checkupdate_open_selected_rows()
 {
-    checkupdate_selected_rows();
-    CORE::get_checkupdate_manager()->run( true );
+    checkupdate_selected_rows( true );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -1837,6 +1929,7 @@ Glib::ustring BBSListViewBase::path2url( const Gtk::TreePath& path )
     switch( type ){
 
         case TYPE_BOARD:
+        case TYPE_BOARD_UPDATE:
             url = DBTREE::url_boardbase( url );
             break;
 
@@ -1866,6 +1959,7 @@ Glib::ustring BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
     switch( type ){
 
         case TYPE_BOARD:
+        case TYPE_BOARD_UPDATE:
             url = DBTREE::url_boardbase( url );
             break;
 
@@ -2052,7 +2146,7 @@ void BBSListViewBase::xml2tree( const std::string& root_name, const std::string&
 
 
 //
-// 移転があったときに行に含まれるURlを変更する
+// 起動時や移転があったときなどに行に含まれるURlを変更する
 //
 void BBSListViewBase::update_urls()
 {
@@ -2081,6 +2175,7 @@ void BBSListViewBase::update_urls()
                     break;
 
                 case TYPE_BOARD: // 板
+                case TYPE_BOARD_UPDATE:
                     url_new = DBTREE::is_board_moved( url );
                     if( ! url_new.empty() ){
                         url_new = DBTREE::url_boardbase( url );
@@ -2127,28 +2222,28 @@ void BBSListViewBase::update_urls()
 
 
 //
-// アイコン表示の切り替え
+// アイコン表示(スレ)の切り替え
 //
-void BBSListViewBase::toggle_icon( const std::string& url )
+void BBSListViewBase::toggle_articleicon( const std::string& url )
 {
     if( ! m_ready_tree ) return;
     if( m_treestore->children().empty() ) return; 
    
-    Gtk::TreePath path = GET_PATH( m_treestore->children().begin() );
-    Gtk::TreeModel::Row row;
-
-    const std::string urldat = DBTREE::url_dat( url );
-    const std::string urlcgi = DBTREE::url_readcgi( url, 0, 0 );
+    const std::string url_dat = DBTREE::url_dat( url );
+    const std::string url_cgi = DBTREE::url_readcgi( url, 0, 0 );
 
     int type = TYPE_THREAD;
     const int status = DBTREE::article_status( url );
     if( status & STATUS_OLD ) type = TYPE_THREAD_OLD;
-    if( status & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
+    else if( status & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
     
 #ifdef _DEBUG
-    std::cout << "BBSListViewBase::toggle_icon url = " << url << " type = " << type << std::endl;
+    std::cout << "BBSListViewBase::toggle_articleicon url = " << url_dat << " type = " << type << std::endl;
 #endif
 
+    Gtk::TreePath path = GET_PATH( m_treestore->children().begin() );
+    Gtk::TreeModel::Row row;
+
     while( 1 ){
 
         if( ( row = m_treeview.get_row( path ) ) ){
@@ -2164,10 +2259,15 @@ void BBSListViewBase::toggle_icon( const std::string& url )
                 case TYPE_THREAD:
                 case TYPE_THREAD_UPDATE:
                 case TYPE_THREAD_OLD:
-                    if( urldat == url_row || urlcgi == url_row ){
+                    if( url_dat == url_row || url_cgi == url_row ){
+#ifdef _DEBUG
+                        std::cout << "hit " << url_dat << " == " << url_row << std::endl;
+#endif
                         row[ m_columns.m_type ] = type;
                         row[ m_columns.m_image ] = XML::get_icon( type );
                     }
+                    path.next();
+                    break;
 
                 default:
                     path.next();
@@ -2188,6 +2288,73 @@ void BBSListViewBase::toggle_icon( const std::string& url )
 }
 
 
+
+//
+// アイコン表示(板)の切り替え
+//
+void BBSListViewBase::toggle_boardicon( const std::string& url )
+{
+    if( ! m_ready_tree ) return;
+    if( m_treestore->children().empty() ) return;
+   
+    const std::string url_subject = DBTREE::url_subject( url );
+
+    int type = TYPE_BOARD;
+    const int status = DBTREE::board_status( url );
+    if( status & STATUS_UPDATE ) type = TYPE_BOARD_UPDATE;
+    
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::toggle_boardicon url = " << url_subject << " type = " << type << std::endl;
+#endif
+
+    Gtk::TreePath path = GET_PATH( m_treestore->children().begin() );
+    Gtk::TreeModel::Row row;
+
+    while( 1 ){
+
+        if( ( row = m_treeview.get_row( path ) ) ){
+
+            const Glib::ustring url_row = row[ m_columns.m_url ];
+
+            switch( row[ m_columns.m_type ] ){
+
+                case TYPE_DIR: // サブディレクトリ
+                    path.down();
+                    break;
+
+                case TYPE_BOARD:
+                case TYPE_BOARD_UPDATE:
+
+                    if( url_subject == DBTREE::url_subject( url_row ) ){
+#ifdef _DEBUG
+                        std::cout << "hit " << url_subject << " == " << url_row << std::endl;
+#endif
+                        row[ m_columns.m_type ] = type;
+                        row[ m_columns.m_image ] = XML::get_icon( type );
+                    }
+                    path.next();
+                    break;
+
+                default:
+                    path.next();
+                    break;
+            }
+        }
+
+        // サブディレクトリ内ならupする
+        else{
+
+            if( path.get_depth() >= 2 ){
+                path.up();
+                path.next();
+            }
+            else break;
+        }
+    }
+}
+
+
+
 //
 // スレの url と 名前を変更
 //
@@ -2212,6 +2379,7 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
 
     const std::string urldat = DBTREE::url_dat( url );
     const std::string urlcgi = DBTREE::url_readcgi( url, 0, 0 );
+    const std::string name_old = MISC::remove_space( DBTREE::article_subject( urldat ) );
 
     int type = TYPE_THREAD;
     const int status = DBTREE::article_status( urldat_new );
@@ -2219,10 +2387,12 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
     if( status & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
 
 #ifdef _DEBUG
-    std::cout << " name = " << name_new
-              << " type = " << type << std::endl;
+    std::cout << "name_new = " << name_new << std::endl
+              << "name_old = " << name_old << std::endl
+              << "type = " << type << std::endl;
 #endif
 
+    bool show_diag = true;
     while( 1 ){
 
         if( ( row = m_treeview.get_row( path ) ) ){
@@ -2238,9 +2408,45 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
                 case TYPE_THREAD:
                 case TYPE_THREAD_UPDATE:
                 case TYPE_THREAD_OLD:
+
                     if( urldat == url_row || urlcgi == url_row ){
+
+                        if( show_diag && CONFIG::show_diag_replace_favorite() ){
+
+                            show_diag = false;
+
+                            SKELETON::MsgCheckDiag mdiag( get_parent_win(),
+                                                          "お気に入りに前スレが登録されています。\n名前とアドレスを新スレの物に置き換えますか？"
+                                                          , "今後表示しない(_D)",
+                                                          Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO
+                                );
+                            mdiag.set_title( "お気に入り更新" );
+                            const int ret = mdiag.run();
+
+                            if( mdiag.get_chkbutton().get_active() ){
+
+                                CONFIG::set_show_diag_replace_favorite( false );
+                                CONFIG::set_replace_favorite_next( ( ret == Gtk::RESPONSE_YES ) );
+                            }
+
+                            if( ret != Gtk::RESPONSE_YES ) return;
+                        }
+
                         row[ m_columns.m_url ] = urldat_new;
-                        row[ m_columns.m_name ] = name_new;
+
+                        // 名前が古いものであったら更新
+                        // 変更されていたらそのまま
+                        const Glib::ustring name_row = row[ m_columns.m_name ];
+#ifdef _DEBUG
+                        std::cout << "name_row = " << name_row << std::endl;
+#endif 
+                        if( MISC::remove_space( name_row ) == name_old ){
+#ifdef _DEBUG
+                            std::cout << "replace name\n";
+#endif 
+                            row[ m_columns.m_name ] = name_new;
+                        }
+
                         row[ m_columns.m_type ] = type;
                         row[ m_columns.m_image ] = XML::get_icon( type );
 
@@ -2363,7 +2569,7 @@ void BBSListViewBase::exec_search()
 // 前検索
 void BBSListViewBase::up_search()
 {
-    m_search_invert = true;
+    set_search_invert( true );
     exec_search();
 }
 
@@ -2372,7 +2578,7 @@ void BBSListViewBase::up_search()
 // 後検索
 void BBSListViewBase::down_search()
 {
-    m_search_invert = false;
+    set_search_invert( false );
     exec_search();
 }
 
@@ -2395,6 +2601,11 @@ void BBSListViewBase::operate_search( const std::string& controlid )
 //
 void BBSListViewBase::append_item()
 {
+    if( m_editlistwin ){
+        m_editlistwin->append_item();
+        return;
+    }
+
     if( CORE::SBUF_size() == 0 ) return;
 
     // 挿入先ダイアログ内で編集を行うとバッファがクリアされてしまうので
@@ -2557,3 +2768,14 @@ void BBSListViewBase::save_xml_impl( const std::string& file, const std::string&
     CACHE::save_rawdata( file, m_document.get_xml() );
 }
 
+
+// undo, redo
+void BBSListViewBase::undo()
+{
+    m_treeview.undo();
+}
+
+void BBSListViewBase::redo()
+{
+    m_treeview.redo();
+}
