@@ -14,6 +14,7 @@
 #include "jdlib/miscutil.h"
 #include "jdlib/miscgtk.h"
 #include "jdlib/jdregex.h"
+#include "skeleton/msgdiag.h"
 
 #include "colorid.h"
 #include "fontid.h"
@@ -36,6 +37,10 @@ std::string get_default_font()
     std::set< std::string > set_fonts = MISC::get_font_families();
 
     // 上の方が優先順位が高い
+#ifdef _WIN32
+    IS_DEFAULT_FONT( "MS PGothic" );
+    IS_DEFAULT_FONT( "MS UI Gothic" );
+#endif
     IS_DEFAULT_FONT( "IPA モナー Pゴシック" );
     IS_DEFAULT_FONT( "IPAMonaPGothic" );
     IS_DEFAULT_FONT( "Mona-VLGothic" );
@@ -64,16 +69,26 @@ ConfigItems::~ConfigItems()
 {}
 
 // 設定読み込み
-const bool ConfigItems::load()
+const bool ConfigItems::load( const bool restore )
 {
-    std::string path_conf = CACHE::path_conf();
+    std::string path_conf;
 
-    // 新設定ファイルが無く、かつキャッシュディレクトリが存在していたら旧ファイルから設定を引き継ぐ
-    if( CACHE::file_exists( path_conf ) != CACHE::EXIST_FILE
-        && CACHE::file_exists( CACHE::path_root() ) == CACHE::EXIST_DIR
-        && CACHE::file_exists( CACHE::path_conf_old() ) == CACHE::EXIST_FILE ){
+    // restoreモード
+    if( restore )
+    {
+        path_conf = CACHE::path_conf_bkup();
+    }
+    else
+    {
+        path_conf = CACHE::path_conf();
 
-            path_conf = CACHE::path_conf_old();
+        // 新設定ファイルが無く、かつキャッシュディレクトリが存在していたら旧ファイルから設定を引き継ぐ
+        if( CACHE::file_exists( path_conf ) != CACHE::EXIST_FILE
+            && CACHE::file_exists( CACHE::path_root() ) == CACHE::EXIST_DIR
+            && CACHE::file_exists( CACHE::path_conf_old() ) == CACHE::EXIST_FILE ){
+
+                path_conf = CACHE::path_conf_old();
+        }
     }
 
     JDLIB::ConfLoader cf( path_conf, std::string() );
@@ -89,345 +104,397 @@ const bool ConfigItems::load()
     set_colors( cf );
 
     // 前回開いたviewを復元するか
-    restore_board = cf.get_option( "restore_board", CONF_RESTORE_BOARD );
-    restore_article = cf.get_option( "restore_article", CONF_RESTORE_ARTICLE );
-    restore_image = cf.get_option( "restore_image", CONF_RESTORE_IMAGE );
+    restore_board = cf.get_option_bool( "restore_board", CONF_RESTORE_BOARD );
+    restore_article = cf.get_option_bool( "restore_article", CONF_RESTORE_ARTICLE );
+    restore_image = cf.get_option_bool( "restore_image", CONF_RESTORE_IMAGE );
 
     // 自前でウィンドウ配置を管理する
-    manage_winpos = cf.get_option( "manage_winpos", CONF_MANAGE_WINPOS );
+    manage_winpos = cf.get_option_bool( "manage_winpos", CONF_MANAGE_WINPOS );
 
     // フォント
     set_fonts( cf );
 
     // レスを参照するときに前に付ける文字
-    ref_prefix = cf.get_option( "ref_prefix", CONF_REF_PREFIX );
+    ref_prefix = cf.get_option_str( "ref_prefix", CONF_REF_PREFIX, 16 );
 
     // 参照文字( ref_prefix ) の後のスペースの数
     // JDLIB::ConfLoader の中で MISC::remove_space() が呼ばれて空白が消えるので別設定とした
-    ref_prefix_space = cf.get_option( "ref_prefix_space", CONF_REF_PREFIX_SPACE );
+    ref_prefix_space = cf.get_option_int( "ref_prefix_space", CONF_REF_PREFIX_SPACE, 0, 16 );
     for( int i = 0; i < ref_prefix_space; ++i ) ref_prefix_space_str += " ";
 
     // キャッシュのルートディレクトリ(旧バージョンとの互換のため残している)
-    path_cacheroot = cf.get_option( "path_cacheroot", CONF_PATH_CACHEROOT );
+    path_cacheroot = cf.get_option_str( "path_cacheroot", CONF_PATH_CACHEROOT );
 
     // 読み込み用プロクシとポート番号
-    use_proxy_for2ch = cf.get_option( "use_proxy_for2ch", CONF_USE_PROXY_FOR2CH );
-    str_tmp = cf.get_option( "proxy_for2ch", "" );
+    use_proxy_for2ch = cf.get_option_bool( "use_proxy_for2ch", CONF_USE_PROXY_FOR2CH );
+    str_tmp = cf.get_option_str( "proxy_for2ch", "" );
     set_proxy_for2ch( str_tmp );
-    proxy_port_for2ch = cf.get_option( "proxy_port_for2ch", CONF_PROXY_PORT_FOR2CH );
+    proxy_port_for2ch = cf.get_option_int( "proxy_port_for2ch", CONF_PROXY_PORT_FOR2CH, 1, 65535 );
 
     // 書き込み用プロクシとポート番号
-    use_proxy_for2ch_w = cf.get_option( "use_proxy_for2ch_w", CONF_USE_PROXY_FOR2CH_W );
-    str_tmp = cf.get_option( "proxy_for2ch_w", "" );
+    use_proxy_for2ch_w = cf.get_option_bool( "use_proxy_for2ch_w", CONF_USE_PROXY_FOR2CH_W );
+    str_tmp = cf.get_option_str( "proxy_for2ch_w", "" );
     set_proxy_for2ch_w( str_tmp );
-    proxy_port_for2ch_w = cf.get_option( "proxy_port_for2ch_w", CONF_PROXY_PORT_FOR2CH_W );
+    proxy_port_for2ch_w = cf.get_option_int( "proxy_port_for2ch_w", CONF_PROXY_PORT_FOR2CH_W, 1, 65535 );
 
     // 2chの外にアクセスするときのプロクシとポート番号
-    use_proxy_for_data = cf.get_option( "use_proxy_for_data", CONF_USE_PROXY_FOR_DATA );
-    str_tmp = cf.get_option( "proxy_for_data", "" );
+    use_proxy_for_data = cf.get_option_bool( "use_proxy_for_data", CONF_USE_PROXY_FOR_DATA );
+    str_tmp = cf.get_option_str( "proxy_for_data", "" );
     set_proxy_for_data( str_tmp );
-    proxy_port_for_data = cf.get_option( "proxy_port_for_data", CONF_PROXY_PORT_FOR_DATA );
+    proxy_port_for_data = cf.get_option_int( "proxy_port_for_data", CONF_PROXY_PORT_FOR_DATA, 1, 65535 );
 
     // 2ch にアクセスするときのエージェント名
-    agent_for2ch = cf.get_option( "agent_for2ch", CONF_AGENT_FOR2CH );
+    agent_for2ch = cf.get_option_str( "agent_for2ch", CONF_AGENT_FOR2CH );
 
     // 2ch外にアクセスするときのエージェント名
-    agent_for_data = cf.get_option( "agent_for_data", CONF_AGENT_FOR_DATA );
+    agent_for_data = cf.get_option_str( "agent_for_data", CONF_AGENT_FOR_DATA );
 
     // 2ch にログインするときのX-2ch-UA
-    x_2ch_ua = cf.get_option( "x_2ch_ua", CONF_X_2CH_UA );
+    x_2ch_ua = cf.get_option_str( "x_2ch_ua", CONF_X_2CH_UA );
 
     // ローダのバッファサイズ
-    loader_bufsize = cf.get_option( "loader_bufsize", CONF_LOADER_BUFSIZE );
+    loader_bufsize = cf.get_option_int( "loader_bufsize", CONF_LOADER_BUFSIZE, 8, 4096 );
 
     // ローダのタイムアウト値
-    loader_timeout = cf.get_option( "loader_timeout", CONF_LOADER_TIMEOUT );
-    loader_timeout_post = cf.get_option( "loader_timeout_post", CONF_LOADER_TIMEOUT_POST ); // ポスト
-    loader_timeout_img = cf.get_option( "loader_timeout_img", CONF_LOADER_TIMEOUT_IMG ); // 画像
-    loader_timeout_checkupdate = cf.get_option( "loader_timeout_checkupdate", CONF_LOADER_TIMEOUT_CHECKUPDATE ); // 更新チェック
+    loader_timeout = cf.get_option_int( "loader_timeout", CONF_LOADER_TIMEOUT, 1, 120 );
+    loader_timeout_post = cf.get_option_int( "loader_timeout_post", CONF_LOADER_TIMEOUT_POST, 1, 120  ); // ポスト
+    loader_timeout_img = cf.get_option_int( "loader_timeout_img", CONF_LOADER_TIMEOUT_IMG, 1, 120 ); // 画像
+    loader_timeout_checkupdate = cf.get_option_int( "loader_timeout_checkupdate", CONF_LOADER_TIMEOUT_CHECKUPDATE, 1, 120 ); // 更新チェック
 
     // ipv6使用
-    use_ipv6 = cf.get_option( "use_ipv6", CONF_USE_IPV6 );
+    use_ipv6 = cf.get_option_bool( "use_ipv6", CONF_USE_IPV6 );
 
     // ブラウザ設定ダイアログのコンボボックスの番号
-    browsercombo_id = cf.get_option( "browsercombo_id", CONF_BROWSER_NO );
+    browsercombo_id = cf.get_option_int( "browsercombo_id", CONF_BROWSER_NO, 0, CORE::get_browser_number() -1 );
 
     // リンクをクリックしたときに実行するコマンド
-    command_openurl = cf.get_option( "command_openurl", CORE::get_browser_name( CONF_BROWSER_NO ) );
+    command_openurl = cf.get_option_str( "command_openurl", CORE::get_browser_name( CONF_BROWSER_NO ) );
 
     // レス番号の上にマウスオーバーしたときに参照ポップアップ表示する
-    refpopup_by_mo = cf.get_option( "refpopup_by_mo", CONF_REFPOPUP_BY_MO );
+    refpopup_by_mo = cf.get_option_bool( "refpopup_by_mo", CONF_REFPOPUP_BY_MO );
 
     // 名前の上にマウスオーバーしたときにポップアップ表示する
-    namepopup_by_mo = cf.get_option( "namepopup_by_mo", CONF_NAMEPOPUP_BY_MO );
+    namepopup_by_mo = cf.get_option_bool( "namepopup_by_mo", CONF_NAMEPOPUP_BY_MO );
 
     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
-    idpopup_by_mo = cf.get_option( "idpopup_by_mo", CONF_IDPOPUP_BY_MO );
+    idpopup_by_mo = cf.get_option_bool( "idpopup_by_mo", CONF_IDPOPUP_BY_MO );
+
+    // 画像のスムージングレベル(0-2, 2が最も高画質かつ低速)
+    imgemb_interp = cf.get_option_int( "imgemb_interp", CONF_IMGEMB_INTERP, 0, 2 );
+    imgmain_interp = cf.get_option_int( "imgmain_interp", CONF_IMGMAIN_INTERP, 0, 2 );
+    imgpopup_interp = cf.get_option_int( "imgpopup_interp", CONF_IMGPOPUP_INTERP, 0, 2 );
 
     // 画像ポップアップサイズ
-    imgpopup_width = cf.get_option( "imgpopup_width", CONF_IMGPOPUP_WIDTH );
-    imgpopup_height = cf.get_option( "imgpopup_height", CONF_IMGPOPUP_HEIGHT );
+    imgpopup_width = cf.get_option_int( "imgpopup_width", CONF_IMGPOPUP_WIDTH, 16, 8192 );
+    imgpopup_height = cf.get_option_int( "imgpopup_height", CONF_IMGPOPUP_HEIGHT, 16, 8192 );
 
     // 画像ポップアップを使用する
-    use_image_popup = cf.get_option( "use_image_popup", CONF_USE_IMAGE_POPUP );
+    use_image_popup = cf.get_option_bool( "use_image_popup", CONF_USE_IMAGE_POPUP );
 
     // 画像ビューを使用する
-    use_image_view = cf.get_option( "use_image_view", CONF_USE_IMAGE_VIEW );
+    use_image_view = cf.get_option_bool( "use_image_view", CONF_USE_IMAGE_VIEW );
 
     // インライン画像を表示する
-    use_inline_image = cf.get_option( "use_inline_image", CONF_INLINE_IMG );
+    use_inline_image = cf.get_option_bool( "use_inline_image", CONF_INLINE_IMG );
 
     // ssspアイコン表示
-    show_ssspicon = cf.get_option( "show_ssspicon", CONF_SHOW_SSSPICON );
+    show_ssspicon = cf.get_option_bool( "show_ssspicon", CONF_SHOW_SSSPICON );
 
     // 画像にモザイクをかける
-    use_mosaic = cf.get_option( "use_mosaic", CONF_USE_MOSAIC );
+    use_mosaic = cf.get_option_bool( "use_mosaic", CONF_USE_MOSAIC );
 
     // モザイクの大きさ
-    mosaic_size = cf.get_option( "mosaic_size", CONF_MOSAIC_SIZE );
+    mosaic_size = cf.get_option_int( "mosaic_size", CONF_MOSAIC_SIZE, 1, 1024 );
 
     // 画像をデフォルトでウィンドウサイズに合わせる
-    zoom_to_fit = cf.get_option( "zoom_to_fit", CONF_ZOOM_TO_FIT );
+    zoom_to_fit = cf.get_option_bool( "zoom_to_fit", CONF_ZOOM_TO_FIT );
 
     // 画像キャッシュ削除の日数
-    del_img_day = cf.get_option( "del_img_day", CONF_DEL_IMG_DAY );
+    del_img_day = cf.get_option_int( "del_img_day", CONF_DEL_IMG_DAY, 0, 65535 );
 
     // 画像あぼーん削除の日数
-    del_imgabone_day = cf.get_option( "del_imgabone_day", CONF_DEL_IMGABONE_DAY );
+    del_imgabone_day = cf.get_option_int( "del_imgabone_day", CONF_DEL_IMGABONE_DAY, 0, 65535 );
 
     // ダウンロードする画像の最大ファイルサイズ(Mbyte)
-    max_img_size = cf.get_option( "max_img_size", CONF_MAX_IMG_SIZE );
+    max_img_size = cf.get_option_int( "max_img_size", CONF_MAX_IMG_SIZE, 1, 1024 );
 
     // 画像の最大サイズ(Mピクセル)
-    max_img_pixel = cf.get_option( "max_img_pixel", CONF_MAX_IMG_PIXEL );
+    max_img_pixel = cf.get_option_int( "max_img_pixel", CONF_MAX_IMG_PIXEL, 1, 1024 );
 
     // JD ホームページのアドレス
-    url_jdhp = cf.get_option( "url_jdhp", CONF_URL_JDHP );
+    url_jdhp = cf.get_option_str( "url_jdhp", CONF_URL_JDHP );
 
-    // 2chの認証サーバ
-    url_login2ch = cf.get_option( "url_login2ch", CONF_LOGIN2CH );
+    // 2chの認証サーバのアドレス
+    url_login2ch = cf.get_option_str( "url_login2ch", CONF_LOGIN2CH );
+
+    // p2の認証サーバのアドレス
+    url_loginp2 = cf.get_option_str( "url_loginp2", CONF_LOGINP2 );
 
     // bbsmenu.htmlのURL
-    url_bbsmenu = cf.get_option( "url_bbsmenu", CONF_URL_BBSMENU );
+    url_bbsmenu = cf.get_option_str( "url_bbsmenu", CONF_URL_BBSMENU );
 
     // bbsmenu.html内にあるリンクは全て板とみなす
-    use_link_as_board = cf.get_option( "use_link_as_board", CONF_USE_LINK_AS_BOARD );
+    use_link_as_board = cf.get_option_bool( "use_link_as_board", CONF_USE_LINK_AS_BOARD );
 
     // 板移転時に確認ダイアログを表示する
-    show_movediag = cf.get_option( "show_movediag", CONF_SHOW_MOVEDIAG );
+    show_movediag = cf.get_option_bool( "show_movediag", CONF_SHOW_MOVEDIAG );
 
     // スレタイ検索用メニュータイトルアドレス
-    menu_search_title = cf.get_option( "menu_search_title", CONF_MENU_SEARCH_TITLE );
-    url_search_title = cf.get_option( "url_search_title", CONF_URL_SEARCH_TITLE );
+    menu_search_title = cf.get_option_str( "menu_search_title", CONF_MENU_SEARCH_TITLE );
+    url_search_title = cf.get_option_str( "url_search_title", CONF_URL_SEARCH_TITLE );
 
     // p2 書き込み用アドレス
-    url_writep2 = cf.get_option( "url_writep2", CONF_URL_WRITEP2 );
-    url_resp2 = cf.get_option( "url_resp2", CONF_URL_RESP2 );
+    url_writep2 = cf.get_option_str( "url_writep2", CONF_URL_WRITEP2 );
+    url_resp2 = cf.get_option_str( "url_resp2", CONF_URL_RESP2 );
 
     // スレタイ検索用正規表現
-    regex_search_title = cf.get_option( "regex_search_title", CONF_REGEX_SEARCH_TITLE );
+    regex_search_title = cf.get_option_str( "regex_search_title", CONF_REGEX_SEARCH_TITLE );
 
     // web検索用メニュータイトルアドレス
-    menu_search_web = cf.get_option( "menu_search_web", CONF_MENU_SEARCH_WEB );
-    url_search_web = cf.get_option( "url_search_web", CONF_URL_SEARCH_WEB );
+    menu_search_web = cf.get_option_str( "menu_search_web", CONF_MENU_SEARCH_WEB );
+    url_search_web = cf.get_option_str( "url_search_web", CONF_URL_SEARCH_WEB );
 
     // ツリービューでgtkrcの設定を使用するか
-    use_tree_gtkrc = cf.get_option( "use_tree_gtkrc", CONF_USE_TREE_GTKRC );
+    use_tree_gtkrc = cf.get_option_bool( "use_tree_gtkrc", CONF_USE_TREE_GTKRC );
 
     // ツリービューの行間スペース
-    tree_ypad = cf.get_option( "tree_ypad", CONF_TREE_YPAD );
+    tree_ypad = cf.get_option_int( "tree_ypad", CONF_TREE_YPAD, 0, 64 );
 
     // 各ビューと枠との間の余白
-    view_margin = cf.get_option( "view_margin", CONF_VIEW_MARGIN );
+    view_margin = cf.get_option_int( "view_margin", CONF_VIEW_MARGIN, 0, 64 );
 
     // スレ一覧で古いスレも表示
-    show_oldarticle = cf.get_option( "show_oldarticle", CONF_SHOW_OLDARTICLE );
+    show_oldarticle = cf.get_option_bool( "show_oldarticle", CONF_SHOW_OLDARTICLE );
 
     // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
-    newthread_hour = cf.get_option( "newthread_hour", CONF_NEWTHREAD_HOUR );
+    newthread_hour = cf.get_option_int( "newthread_hour", CONF_NEWTHREAD_HOUR, 1, 65535 );
 
     // スレ一覧でインクリメント検索をする
-    inc_search_board = cf.get_option( "inc_search_board", CONF_INC_SEARCH_BOARD );
+    inc_search_board = cf.get_option_bool( "inc_search_board", CONF_INC_SEARCH_BOARD );
 
     // スレ一覧でdeleteを押したときに確認ダイアログを表示する
-    show_deldiag = cf.get_option( "show_deldiag", CONF_SHOW_DELDIAG );
+    show_deldiag = cf.get_option_bool( "show_deldiag", CONF_SHOW_DELDIAG );
 
     // ツリービューのスクロール量(行数)
-    tree_scroll_size = cf.get_option( "tree_scroll_size", CONF_TREE_SCROLL_SIZE );
+    tree_scroll_size = cf.get_option_int( "tree_scroll_size", CONF_TREE_SCROLL_SIZE, 1, 64 );
 
     // スレビューのスクロール量
-    scroll_size = cf.get_option( "scroll_size", CONF_SCROLL_SIZE );
+    scroll_size = cf.get_option_int( "scroll_size", CONF_SCROLL_SIZE, 1, 64 );
 
     // スレビューのスクロール量(キー上下)
-    key_scroll_size = cf.get_option( "key_scroll_size", CONF_KEY_SCROLL_SIZE );
+    key_scroll_size = cf.get_option_int( "key_scroll_size", CONF_KEY_SCROLL_SIZE, 1, 64 );
 
     // スレビューの高速スクロール量(キー上下・ ページ高 - 行高 * key_fastscroll_size )
-    key_fastscroll_size = cf.get_option( "key_fastscroll_size", CONF_KEY_FASTSCROLL_SIZE );
+    key_fastscroll_size = cf.get_option_int( "key_fastscroll_size", CONF_KEY_FASTSCROLL_SIZE, 1, 64 );
 
     // スレビューでリロード後に一番下までスクロール
-    jump_after_reload = cf.get_option( "jump_after_reload", CONF_JUMP_AFTER_RELOAD );
+    jump_after_reload = cf.get_option_bool( "jump_after_reload", CONF_JUMP_AFTER_RELOAD );
 
     // スレビューでリロード後に新着までスクロール
-    jump_new_after_reload = cf.get_option( "jump_new_after_reload", CONF_JUMP_NEW_AFTER_RELOAD );
+    jump_new_after_reload = cf.get_option_bool( "jump_new_after_reload", CONF_JUMP_NEW_AFTER_RELOAD );
 
     // 実況モード
-    live_mode = cf.get_option( "live_mode", LIVE_SCRMODE_VARIABLE );
+    live_mode = cf.get_option_int( "live_mode", LIVE_SCRMODE_VARIABLE, 0, LIVE_SCRMODE_NUM -1 );
 
     // 実況速度
-    live_speed = cf.get_option( "live_speed", CONF_LIVE_SPEED );
+    live_speed = cf.get_option_int( "live_speed", CONF_LIVE_SPEED, 1, 1024 );
 
     // 実況のスクロールモードを切り替えるしきい値
-    live_threshold = cf.get_option( "live_threshold", CONF_LIVE_THRESHOLD );
+    live_threshold = cf.get_option_int( "live_threshold", CONF_LIVE_THRESHOLD, 1, 1024 );
 
     // 板一覧でカテゴリを常にひとつだけ開く
-    open_one_category = cf.get_option( "open_one_category", CONF_OPEN_ONE_CATEGORY );
+    open_one_category = cf.get_option_bool( "open_one_category", CONF_OPEN_ONE_CATEGORY );
 
     // お気に入りでカテゴリを常にひとつだけ開く
-    open_one_favorite = cf.get_option( "open_one_favorite", CONF_OPEN_ONE_FAVORITE );
+    open_one_favorite = cf.get_option_bool( "open_one_favorite", CONF_OPEN_ONE_FAVORITE );
 
     // 書き込み時に書き込み確認ダイアログを出さない
-    always_write_ok = cf.get_option( "always_write_ok", CONF_ALWAYS_WRITE_OK );
+    always_write_ok = cf.get_option_bool( "always_write_ok", CONF_ALWAYS_WRITE_OK );
 
     // 書き込みログを保存
-    save_postlog = cf.get_option( "save_postlog", CONF_SAVE_POSTLOG );
+    save_postlog = cf.get_option_bool( "save_postlog", CONF_SAVE_POSTLOG );
 
     // 書き込みログの最大サイズ
-    maxsize_postlog = cf.get_option( "maxsize_postlog", CONF_MAXSIZE_POSTLOG );
+    maxsize_postlog = cf.get_option_int( "maxsize_postlog", CONF_MAXSIZE_POSTLOG, 1024, 1024 * 1024 );
 
     // 書き込み履歴を保存
-    save_posthist = cf.get_option( "save_posthist", CONF_SAVE_POSTHIST );
+    save_posthist = cf.get_option_bool( "save_posthist", CONF_SAVE_POSTHIST );
 
     // 「書き込み中」のダイアログを表示しない
-    hide_writing_dialog = cf.get_option( "hide_writing_dialog", CONF_HIDE_WRITING_DIALOG );
+    hide_writing_dialog = cf.get_option_bool( "hide_writing_dialog", CONF_HIDE_WRITING_DIALOG );
 
     // 非アクティブ時に書き込みビューを折りたたむ
-    fold_message = cf.get_option( "fold_message", CONF_FOLD_MESSAGE );
+    fold_message = cf.get_option_bool( "fold_message", CONF_FOLD_MESSAGE );
 
     // ポップアップとカーソルの間のマージン
-    margin_popup = cf.get_option( "margin_popup", CONF_MARGIN_POPUP );
+    margin_popup = cf.get_option_int( "margin_popup", CONF_MARGIN_POPUP, 1, 1024 );
 
     // 画像ポップアップとカーソルの間のマージン
-    margin_imgpopup = cf.get_option( "margin_imgpopup", CONF_MARGIN_IMGPOPUP );
+    margin_imgpopup = cf.get_option_int( "margin_imgpopup", CONF_MARGIN_IMGPOPUP, 1, 1024 );
 
     // マウスジェスチャの判定開始半径
-    mouse_radius = cf.get_option( "mouse_radius", CONF_MOUSE_RADIUS );
+    mouse_radius = cf.get_option_int( "mouse_radius", CONF_MOUSE_RADIUS, 4, 1024 );
 
     // 履歴の保持数
-    history_size = cf.get_option( "history_size", CONF_HISTORY );
+    history_size = cf.get_option_int( "history_size", CONF_HISTORY, 0, 65535 );
 
     // AA履歴の保持数
-    aahistory_size = cf.get_option( "aahistory_size", CONF_AAHISTORY );
+    aahistory_size = cf.get_option_int( "aahistory_size", CONF_AAHISTORY, 0, 65535 );
 
     // 0以上なら多重ポップアップの説明を表示する
-    instruct_popup = cf.get_option( "instruct_popup", CONF_INSTRUCT_POPUP );    
+    instruct_popup = cf.get_option_int( "instruct_popup", CONF_INSTRUCT_POPUP, 0, CONF_INSTRUCT_POPUP );
 
     // スレビューを開いたときにスレ一覧との切り替え方法を説明する
-    instruct_tglart = cf.get_option( "instruct_tglart", CONF_INSTRUCT_TGLART );
+    instruct_tglart = cf.get_option_bool( "instruct_tglart", CONF_INSTRUCT_TGLART );
     instruct_tglart_end = false;
 
     // 画像ビューを開いたときにスレビューとの切り替え方法を説明する
-    instruct_tglimg = cf.get_option( "instruct_tglimg", CONF_INSTRUCT_TGLIMG );
+    instruct_tglimg = cf.get_option_bool( "instruct_tglimg", CONF_INSTRUCT_TGLIMG );
     instruct_tglimg_end = false;
-    
+
     // 下線位置
-    adjust_underline_pos = cf.get_option( "adjust_underline_pos", ( double )CONF_ADJUST_UNDERLINE_POS );
+    adjust_underline_pos = cf.get_option_double( "adjust_underline_pos", ( double )CONF_ADJUST_UNDERLINE_POS, ( double )0, ( double )64 );
 
     // 行間スペース
-    adjust_line_space = cf.get_option( "adjust_line_space", ( double )CONF_ADJUST_LINE_SPACE );
+    adjust_line_space = cf.get_option_double( "adjust_line_space", ( double )CONF_ADJUST_LINE_SPACE, ( double )0, ( double )64 );
 
     // リンク下線を表示
-    draw_underline = cf.get_option( "draw_underline", CONF_DRAW_UNDERLINE );
+    draw_underline = cf.get_option_bool( "draw_underline", CONF_DRAW_UNDERLINE );
 
     // スレビューで文字幅の近似を厳密にする
-    strict_char_width = cf.get_option( "strict_char_width", CONF_STRICT_CHAR_WIDTH );
+    strict_char_width = cf.get_option_bool( "strict_char_width", CONF_STRICT_CHAR_WIDTH );
 
     // スレビューで発言数(ID)をカウントする
-    check_id = cf.get_option( "check_id", CONF_CHECK_ID );
+    check_id = cf.get_option_bool( "check_id", CONF_CHECK_ID );
 
     // レス参照で色を変える回数
-    num_reference_high = cf.get_option( "num_reference_high", CONF_NUM_REFERENCE_HIGH );
-    num_reference_low = cf.get_option( "num_reference_low", CONF_NUM_REFERENCE_LOW );
+    num_reference_high = cf.get_option_int( "num_reference_high", CONF_NUM_REFERENCE_HIGH, 1, 256 );
+    num_reference_low = cf.get_option_int( "num_reference_low", CONF_NUM_REFERENCE_LOW, 1, 128 );
 
     // 発言数で色を変える回数
-    num_id_high = cf.get_option( "num_id_high", CONF_NUM_ID_HIGH );
-    num_id_low = cf.get_option( "num_id_low", CONF_NUM_ID_LOW );
+    num_id_high = cf.get_option_int( "num_id_high", CONF_NUM_ID_HIGH, 1, 256 );
+    num_id_low = cf.get_option_int( "num_id_low", CONF_NUM_ID_LOW, 1, 128 );
 
     // datのパース時にURL判定を甘くする(^なども含める)
-    loose_url = cf.get_option( "loose_url", CONF_LOOSE_URL );
+    loose_url = cf.get_option_bool( "loose_url", CONF_LOOSE_URL );
 
     // ユーザーコマンドで選択できない項目を非表示にする
-    hide_usrcmd = cf.get_option( "hide_usrcmd", CONF_HIDE_USRCMD );
+    hide_usrcmd = cf.get_option_bool( "hide_usrcmd", CONF_HIDE_USRCMD );
 
     // スレビューで再読み込みボタンを押したときに全タブを更新する
-    reload_allthreads = cf.get_option( "reload_allthreads", CONF_RELOAD_ALLTHREAD );
+    reload_allthreads = cf.get_option_bool( "reload_allthreads", CONF_RELOAD_ALLTHREAD );
 
     // タブに表示する文字列の最小値
-    tab_min_str = cf.get_option( "tab_min_str", CONF_TAB_MIN_STR );
+    tab_min_str = cf.get_option_int( "tab_min_str", CONF_TAB_MIN_STR, 1, 256 );
 
     // タブにアイコンを表示するか
-    show_tab_icon = cf.get_option( "show_tab_icon", CONF_SHOW_TAB_ICON );
+    show_tab_icon = cf.get_option_bool( "show_tab_icon", CONF_SHOW_TAB_ICON );
 
     // スレビューに書き込みマークを表示するか
-    show_post_mark = cf.get_option( "show_post_mark", CONF_SHOW_POST_MARK );
+    show_post_mark = cf.get_option_bool( "show_post_mark", CONF_SHOW_POST_MARK );
 
     // ボタンをフラットにするか
-    flat_button = cf.get_option( "flat_button", CONF_FLAT_BUTTON );
+    flat_button = cf.get_option_bool( "flat_button", CONF_FLAT_BUTTON );
+
+    // ツールバーの背景描画
+    draw_toolbarback = cf.get_option_bool( "draw_toolbarback", CONF_DRAW_TOOLBARBACK );
 
     std::list< std::string > list_tmp;
     std::list< std::string >::iterator it_tmp;
 
     // スレ あぼーん word
-    str_tmp = cf.get_option( "abonewordthread", "" );
+    str_tmp = cf.get_option_str( "abonewordthread", "" );
     if( ! str_tmp.empty() ) list_abone_word_thread = MISC::strtolist( str_tmp );
 
     // スレ あぼーん regex
-    str_tmp = cf.get_option( "aboneregexthread", "" );
+    str_tmp = cf.get_option_str( "aboneregexthread", "" );
     if( ! str_tmp.empty() ) list_abone_regex_thread = MISC::strtolist( str_tmp );
 
     // スレ あぼーん( レス数 )
-    abone_number_thread = cf.get_option( "abone_number_thread", CONF_ABONE_NUMBER_THREAD );
+    abone_number_thread = cf.get_option_int( "abone_number_thread", CONF_ABONE_NUMBER_THREAD, 0, 9999 );
 
     // スレ あぼーん( スレ立てからの経過時間 )
-    abone_hour_thread = cf.get_option( "abone_hour_thread", CONF_ABONE_HOUR_THREAD );
+    abone_hour_thread = cf.get_option_int( "abone_hour_thread", CONF_ABONE_HOUR_THREAD, 0, 9999 );
 
     // あぼーん name
-    str_tmp = cf.get_option( "abonename", "" );
+    str_tmp = cf.get_option_str( "abonename", "" );
     if( ! str_tmp.empty() ) list_abone_name = MISC::strtolist( str_tmp );
 
     // あぼーん word
-    str_tmp = cf.get_option( "aboneword", "" );
+    str_tmp = cf.get_option_str( "aboneword", "" );
     if( ! str_tmp.empty() ) list_abone_word = MISC::strtolist( str_tmp );
 
     // あぼーん regex
-    str_tmp = cf.get_option( "aboneregex", "" );
+    str_tmp = cf.get_option_str( "aboneregex", "" );
     if( ! str_tmp.empty() ) list_abone_regex = MISC::strtolist( str_tmp );
 
     // デフォルトで透明、連鎖あぼーんをするか
-    abone_transparent = cf.get_option( "abone_transparent", CONF_ABONE_TRANSPARENT );
-    abone_chain = cf.get_option( "abone_chain", CONF_ABONE_CHAIN );
+    abone_transparent = cf.get_option_bool( "abone_transparent", CONF_ABONE_TRANSPARENT );
+    abone_chain = cf.get_option_bool( "abone_chain", CONF_ABONE_CHAIN );
 
     // 右ペーンが空の時にサイドバーを閉じるか
-    expand_sidebar = cf.get_option( "expand_sidebar", CONF_EXPAND_SIDEBAR );
+    expand_sidebar = cf.get_option_bool( "expand_sidebar", CONF_EXPAND_SIDEBAR );
 
     // 3ペーン時にスレ一覧やスレビューを最大化する
-    expand_rpane = cf.get_option( "expand_rpane", CONF_EXPAND_RPANE );
+    expand_rpane = cf.get_option_bool( "expand_rpane", CONF_EXPAND_RPANE );
 
     // 次スレ検索の類似度のしきい値
-    threshold_next = cf.get_option( "threshold_next", CONF_THRESHOLD_NEXT );
+    threshold_next = cf.get_option_int( "threshold_next", CONF_THRESHOLD_NEXT, 1, 10 );
 
     // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-    replace_favorite_next = cf.get_option( "replace_favorite_next", CONF_REPLACE_FAVORITE_NEXT );
+    replace_favorite_next = cf.get_option_bool( "replace_favorite_next", CONF_REPLACE_FAVORITE_NEXT );
+
+    // お気に入りの自動更新をするかダイアログを出す
+    show_diag_replace_favorite = cf.get_option_bool( "show_diag_replace_favorite", CONF_SHOW_DIAG_REPLACE_FAVORITE );
 
     // スレをお気に入りに追加したときにしおりをセットする
-    bookmark_drop = cf.get_option( "bookmark_drop", CONF_BOOKMARK_DROP );
+    bookmark_drop = cf.get_option_bool( "bookmark_drop", CONF_BOOKMARK_DROP );
+
+    // お気に入りの更新チェック時に板の更新もチェックする
+    check_update_board  = cf.get_option_bool( "check_update_board", CONF_CHECK_UPDATE_BOARD );
+
+    // Ctrl+qでウィンドウを閉じない
+    disable_close = cf.get_option_bool( "disable_close", CONF_DISABLE_CLOSE );
+
+    // まちBBSの取得に offlaw.cgi を使用する
+    use_machi_offlaw = cf.get_option_bool( "use_machi_offlaw", CONF_USE_MACHI_OFFLAW );
 
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
-    migemodict_path = cf.get_option( "migemodict_path", CONF_MIGEMO_PATH );
+    migemodict_path = cf.get_option_str( "migemodict_path", CONF_MIGEMO_PATH );
 #endif
 
     m_loaded = true;
 
+    // 設定値に壊れている物がある
+    if( cf.is_broken() )
+    {
+        std::string msg;
+        Gtk::MessageDialog *mdiag;
+
+        // 非resotreモードでバックアップが存在する
+        if( ! restore && CACHE::file_exists( CACHE::path_conf_bkup() ) == CACHE::EXIST_FILE )
+        {
+            msg = path_conf + "に異常な値があります。全設定をバックアップから復元しますか？";
+            mdiag = new Gtk::MessageDialog( msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            int ret = mdiag->run();
+            delete mdiag;
+            if( ret != Gtk::RESPONSE_YES ) load( true ); // resotreモードで再帰
+        }
+        else
+        {
+            msg = path_conf + "に異常な値があるため、一部をデフォルトに設定しました。";
+            mdiag = new Gtk::MessageDialog( msg );
+            mdiag->run();
+            delete mdiag;
+        }
+    }
+    // 正常ならバックアップ
+    else
+    {
+        save_impl( CACHE::path_conf_bkup() );
+    }
+
     return ! cf.empty();
 }
 
@@ -456,6 +523,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "manage_winpos", manage_winpos );
     cf.update( "url_jdhp", url_jdhp );
     cf.update( "url_login2ch", url_login2ch );
+    cf.update( "url_loginp2", url_loginp2 );
     cf.update( "url_bbsmenu", url_bbsmenu );
     cf.update( "use_link_as_board", use_link_as_board );
     cf.update( "show_movediag", show_movediag );
@@ -518,6 +586,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "namepopup_by_mo", namepopup_by_mo );
     cf.update( "idpopup_by_mo", idpopup_by_mo );
 
+    cf.update( "imgemb_interp", imgemb_interp );
+    cf.update( "imgmain_interp", imgmain_interp );
+    cf.update( "imgpopup_interp", imgpopup_interp );
     cf.update( "imgpopup_width", imgpopup_width );
     cf.update( "imgpopup_height", imgpopup_height );
     cf.update( "use_image_popup", use_image_popup );
@@ -629,6 +700,8 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "flat_button", flat_button );
 
+    cf.update( "draw_toolbarback", draw_toolbarback );
+
     // スレあぼーん情報
     std::string str_abone_word_thread = MISC::listtostr( list_abone_word_thread );
     std::string str_abone_regex_thread = MISC::listtostr( list_abone_regex_thread );
@@ -656,7 +729,11 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "threshold_next", threshold_next );
     cf.update( "replace_favorite_next", replace_favorite_next );
+    cf.update( "show_diag_replace_favorite", show_diag_replace_favorite );
     cf.update( "bookmark_drop", bookmark_drop );
+    cf.update( "check_update_board", check_update_board );
+    cf.update( "disable_close", disable_close );
+    cf.update( "use_machi_offlaw", use_machi_offlaw );
 
 #ifdef HAVE_MIGEMO_H
     cf.update( "migemodict_path", migemodict_path );
@@ -674,19 +751,19 @@ void ConfigItems::set_fonts( JDLIB::ConfLoader& cf )
     const std::string defaultfont = get_default_font();
 
     // フォント
-    fontname[ FONT_MAIN ] = cf.get_option( "fontname_main", defaultfont + " " + std::string( CONF_FONTSIZE_THREAD ) );
+    fontname[ FONT_MAIN ] = cf.get_option_str( "fontname_main", defaultfont + " " + std::string( CONF_FONTSIZE_THREAD ) );
 
     // ポップアップのフォント
-    fontname[ FONT_POPUP ] = cf.get_option( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
+    fontname[ FONT_POPUP ] = cf.get_option_str( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
 
     // スレ一覧のフォント
-    fontname[ FONT_BBS ] = cf.get_option( "fontname_bbs", defaultfont + " " + std::string( CONF_FONTSIZE_TREE ) );
+    fontname[ FONT_BBS ] = cf.get_option_str( "fontname_bbs", defaultfont + " " + std::string( CONF_FONTSIZE_TREE ) );
 
     // 板一覧のフォント
-    fontname[ FONT_BOARD ] = cf.get_option( "fontname_board", fontname[ FONT_BBS ] );
+    fontname[ FONT_BOARD ] = cf.get_option_str( "fontname_board", fontname[ FONT_BBS ] );
 
     // 書き込みウィンドウのフォント
-    fontname[ FONT_MESSAGE ] = cf.get_option( "fontname_message", fontname[ FONT_MAIN ] );
+    fontname[ FONT_MESSAGE ] = cf.get_option_str( "fontname_message", fontname[ FONT_MAIN ] );
 
     // Gtk::Entryのデフォルトフォント
     fontname[ FONT_ENTRY_DEFAULT ] = MISC::get_entry_font();
@@ -709,110 +786,110 @@ void ConfigItems::reset_fonts()
 //
 void ConfigItems::set_colors( JDLIB::ConfLoader& cf )
 {
-    // 文字色
-    str_color[ COLOR_CHAR ] = cf.get_option( "cl_char", CONF_COLOR_CHAR );
+    // 文字色 13 = "#FFFFFFFFFFFF" or "#%DDx%DDx%DDx"
+    str_color[ COLOR_CHAR ] = cf.get_option_str( "cl_char", CONF_COLOR_CHAR, 13 );
 
     // 名前欄の文字色
-    str_color[ COLOR_CHAR_NAME ] = cf.get_option( "cl_char_name", CONF_COLOR_CHAR_NAME );
+    str_color[ COLOR_CHAR_NAME ] = cf.get_option_str( "cl_char_name", CONF_COLOR_CHAR_NAME, 13 );
 
     // トリップ等の名前欄の文字色
-    str_color[ COLOR_CHAR_NAME_B ] = cf.get_option( "cl_char_name_b", CONF_COLOR_CHAR_NAME_B );
+    str_color[ COLOR_CHAR_NAME_B ] = cf.get_option_str( "cl_char_name_b", CONF_COLOR_CHAR_NAME_B, 13 );
 
     // 名前無し時の名前欄の文字色
-    str_color[ COLOR_CHAR_NAME_NOMAIL ] = cf.get_option( "cl_char_name_nomail", CONF_COLOR_CHAR_NAME_NOMAIL );
+    str_color[ COLOR_CHAR_NAME_NOMAIL ] = cf.get_option_str( "cl_char_name_nomail", CONF_COLOR_CHAR_NAME_NOMAIL, 13 );
 
     // ageの時のメール欄の文字色
-    str_color[ COLOR_CHAR_AGE ] = cf.get_option( "cl_char_age", CONF_COLOR_CHAR_AGE );
+    str_color[ COLOR_CHAR_AGE ] = cf.get_option_str( "cl_char_age", CONF_COLOR_CHAR_AGE, 13 );
 
     // 選択範囲の文字色
-    str_color[ COLOR_CHAR_SELECTION ] = cf.get_option( "cl_char_selection", CONF_COLOR_CHAR_SELECTION );
+    str_color[ COLOR_CHAR_SELECTION ] = cf.get_option_str( "cl_char_selection", CONF_COLOR_CHAR_SELECTION, 13 );
 
     // ハイライトの文字色
-    str_color[ COLOR_CHAR_HIGHLIGHT ] = cf.get_option( "cl_char_highlight", CONF_COLOR_CHAR_HIGHLIGHT );
+    str_color[ COLOR_CHAR_HIGHLIGHT ] = cf.get_option_str( "cl_char_highlight", CONF_COLOR_CHAR_HIGHLIGHT, 13 );
 
     // リンク(通常)の文字色
-    str_color[ COLOR_CHAR_LINK ] = cf.get_option( "cl_char_link", CONF_COLOR_CHAR_LINK );
+    str_color[ COLOR_CHAR_LINK ] = cf.get_option_str( "cl_char_link", CONF_COLOR_CHAR_LINK, 13 );
 
     // リンク(複数)の文字色
-    str_color[ COLOR_CHAR_LINK_LOW ] = cf.get_option( "cl_char_link_low", CONF_COLOR_CHAR_LINK_LOW );
+    str_color[ COLOR_CHAR_LINK_LOW ] = cf.get_option_str( "cl_char_link_low", CONF_COLOR_CHAR_LINK_LOW, 13 );
 
     // リンク(多数)の文字色
-    str_color[ COLOR_CHAR_LINK_HIGH ] = cf.get_option( "cl_char_link_high", CONF_COLOR_CHAR_LINK_HIGH );
+    str_color[ COLOR_CHAR_LINK_HIGH ] = cf.get_option_str( "cl_char_link_high", CONF_COLOR_CHAR_LINK_HIGH, 13 );
 
     // メッセージビューの文字色
-    str_color[ COLOR_CHAR_MESSAGE ] = cf.get_option( "cl_char_message", CONF_COLOR_CHAR_MESSAGE );
+    str_color[ COLOR_CHAR_MESSAGE ] = cf.get_option_str( "cl_char_message", CONF_COLOR_CHAR_MESSAGE, 13 );
 
     // メッセージビュー(選択範囲)の文字色
-    str_color[ COLOR_CHAR_MESSAGE_SELECTION ] = cf.get_option( "cl_char_message_selection", CONF_COLOR_CHAR_MESSAGE_SELECTION );
+    str_color[ COLOR_CHAR_MESSAGE_SELECTION ] = cf.get_option_str( "cl_char_message_selection", CONF_COLOR_CHAR_MESSAGE_SELECTION, 13 );
 
     // Gtk::Entryのデフォルトの文字色
     str_color[ COLOR_CHAR_ENTRY_DEFAULT ] = MISC::get_entry_color_text();
 
     // 画像(キャッシュ無)の色
-    str_color[ COLOR_IMG_NOCACHE ] = cf.get_option( "cl_img_nocache", CONF_COLOR_IMG_NOCACHE );
+    str_color[ COLOR_IMG_NOCACHE ] = cf.get_option_str( "cl_img_nocache", CONF_COLOR_IMG_NOCACHE, 13 );
 
     // 画像(キャッシュ有)の色
-    str_color[ COLOR_IMG_CACHED ] = cf.get_option( "cl_img_cached", CONF_COLOR_IMG_CACHED );
+    str_color[ COLOR_IMG_CACHED ] = cf.get_option_str( "cl_img_cached", CONF_COLOR_IMG_CACHED, 13 );
 
     // 画像(ロード中)の色
-    str_color[ COLOR_IMG_LOADING ] = cf.get_option( "cl_img_loading", CONF_COLOR_IMG_LOADING );
+    str_color[ COLOR_IMG_LOADING ] = cf.get_option_str( "cl_img_loading", CONF_COLOR_IMG_LOADING, 13 );
 
     // 画像(エラー)の色
-    str_color[ COLOR_IMG_ERR ] = cf.get_option( "cl_img_err", CONF_COLOR_IMG_ERR );
+    str_color[ COLOR_IMG_ERR ] = cf.get_option_str( "cl_img_err", CONF_COLOR_IMG_ERR, 13 );
 
     // スレ背景色
-    str_color[ COLOR_BACK ] = cf.get_option( "cl_back", CONF_COLOR_BACK );
+    str_color[ COLOR_BACK ] = cf.get_option_str( "cl_back", CONF_COLOR_BACK, 13 );
 
     // ポップアップの背景色
-    str_color[ COLOR_BACK_POPUP ] = cf.get_option( "cl_back_popup", CONF_COLOR_BACK_POPUP );
+    str_color[ COLOR_BACK_POPUP ] = cf.get_option_str( "cl_back_popup", CONF_COLOR_BACK_POPUP, 13 );
 
     // 選択範囲の背景色
-    str_color[ COLOR_BACK_SELECTION ] = cf.get_option( "cl_back_selection", CONF_COLOR_BACK_SELECTION );
+    str_color[ COLOR_BACK_SELECTION ] = cf.get_option_str( "cl_back_selection", CONF_COLOR_BACK_SELECTION, 13 );
 
     // ハイライトの背景色
-    str_color[ COLOR_BACK_HIGHLIGHT ] = cf.get_option( "cl_back_highlight", CONF_COLOR_BACK_HIGHLIGHT );
+    str_color[ COLOR_BACK_HIGHLIGHT ] = cf.get_option_str( "cl_back_highlight", CONF_COLOR_BACK_HIGHLIGHT, 13 );
 
     // ハイライトの背景色(ツリー用)
-    str_color[ COLOR_BACK_HIGHLIGHT_TREE ] = cf.get_option( "cl_back_highlight_tree", CONF_COLOR_BACK_HIGHLIGHT_TREE );
+    str_color[ COLOR_BACK_HIGHLIGHT_TREE ] = cf.get_option_str( "cl_back_highlight_tree", CONF_COLOR_BACK_HIGHLIGHT_TREE, 13 );
 
     // メッセージビューの背景色
-    str_color[ COLOR_BACK_MESSAGE ] = cf.get_option( "cl_back_message", CONF_COLOR_BACK_MESSAGE );
+    str_color[ COLOR_BACK_MESSAGE ] = cf.get_option_str( "cl_back_message", CONF_COLOR_BACK_MESSAGE, 13 );
 
     // メッセージビューの選択色
-    str_color[ COLOR_BACK_MESSAGE_SELECTION ] = cf.get_option( "cl_back_message_selection", CONF_COLOR_BACK_MESSAGE_SELECTION );
+    str_color[ COLOR_BACK_MESSAGE_SELECTION ] = cf.get_option_str( "cl_back_message_selection", CONF_COLOR_BACK_MESSAGE_SELECTION, 13 );
 
     // Gtk::Entryのデフォルトの背景色
     str_color[ COLOR_BACK_ENTRY_DEFAULT ] = MISC::get_entry_color_base();
 
     // 新着セパレータ
-    str_color[ COLOR_SEPARATOR_NEW ] = cf.get_option( "cl_sepa_new", CONF_COLOR_SEPARATOR_NEW );
+    str_color[ COLOR_SEPARATOR_NEW ] = cf.get_option_str( "cl_sepa_new", CONF_COLOR_SEPARATOR_NEW, 13 );
 
     // ポップアップフレーム色
-    str_color[ COLOR_FRAME ] = cf.get_option( "cl_frame", CONF_COLOR_FRAME );
+    str_color[ COLOR_FRAME ] = cf.get_option_str( "cl_frame", CONF_COLOR_FRAME, 13 );
 
     // オートスクロールマーカー色
-    str_color[ COLOR_MARKER ] = cf.get_option( "cl_marker", CONF_COLOR_MARKER );
+    str_color[ COLOR_MARKER ] = cf.get_option_str( "cl_marker", CONF_COLOR_MARKER, 13 );
 
     // 板一覧の文字
-    str_color[ COLOR_CHAR_BBS ] = cf.get_option( "cl_chr_bbs", CONF_COLOR_CHAR_BBS );
+    str_color[ COLOR_CHAR_BBS ] = cf.get_option_str( "cl_chr_bbs", CONF_COLOR_CHAR_BBS, 13 );
 
     // 板一覧のコメント
-    str_color[ COLOR_CHAR_BBS_COMMENT ] = cf.get_option( "cl_chr_bbs_com", CONF_COLOR_CHAR_BBS_COMMENT );
+    str_color[ COLOR_CHAR_BBS_COMMENT ] = cf.get_option_str( "cl_chr_bbs_com", CONF_COLOR_CHAR_BBS_COMMENT, 13 );
 
     // スレ一覧の文字
-    str_color[ COLOR_CHAR_BOARD ] = cf.get_option( "cl_chr_board", CONF_COLOR_CHAR_BOARD );
+    str_color[ COLOR_CHAR_BOARD ] = cf.get_option_str( "cl_chr_board", CONF_COLOR_CHAR_BOARD, 13 );
 
     // 板一覧の背景色
-    str_color[ COLOR_BACK_BBS ] = cf.get_option( "cl_back_bbs", CONF_COLOR_BACK_BBS );
+    str_color[ COLOR_BACK_BBS ] = cf.get_option_str( "cl_back_bbs", CONF_COLOR_BACK_BBS, 13 );
 
     // 板一覧の背景色(偶数行)
-    str_color[ COLOR_BACK_BBS_EVEN ] = cf.get_option( "cl_back_bbs_even", CONF_COLOR_BACK_BBS_EVEN );
+    str_color[ COLOR_BACK_BBS_EVEN ] = cf.get_option_str( "cl_back_bbs_even", CONF_COLOR_BACK_BBS_EVEN, 13 );
 
     // スレ一覧の背景色
-    str_color[ COLOR_BACK_BOARD ] = cf.get_option( "cl_back_board", CONF_COLOR_BACK_BOARD );
+    str_color[ COLOR_BACK_BOARD ] = cf.get_option_str( "cl_back_board", CONF_COLOR_BACK_BOARD, 13 );
 
     // スレ一覧の背景色(偶数行)
-    str_color[ COLOR_BACK_BOARD_EVEN ] = cf.get_option( "cl_back_board_even", CONF_COLOR_BACK_BOARD_EVEN );
+    str_color[ COLOR_BACK_BOARD_EVEN ] = cf.get_option_str( "cl_back_board_even", CONF_COLOR_BACK_BOARD_EVEN, 13 );
 }
 
 
