@@ -68,6 +68,8 @@ Img::Img( const std::string& url )
     std::cout << "Img::Img url = " << m_url <<  std::endl;
 #endif
 
+    set_priority_low();
+
     reset();
 }
 
@@ -111,10 +113,43 @@ void Img::clear()
     m_height = 0;
     m_width_emb = 0;
     m_height_emb = 0;
+    m_width_mosaic = 0;
+    m_height_mosaic = 0;
     m_abone = false;
 }
 
 
+// スレ埋め込み画像の高さ、幅
+const int Img::get_width_emb()
+{
+    if( ! m_width_emb ) set_embedded_size();
+
+    return m_width_emb;
+}
+
+const int Img::get_height_emb()
+{
+    if( ! m_height_emb ) set_embedded_size();
+
+    return m_height_emb;
+}
+
+
+// モザイク処理時に縮小するサイズ
+const int Img::get_width_mosaic()
+{
+    if( ! m_width_mosaic ) set_mosaic_size();
+
+    return m_width_mosaic;
+}
+
+const int Img::get_height_mosaic()
+{
+    if( ! m_height_mosaic ) set_mosaic_size();
+
+    return m_height_mosaic;
+}
+
 
 const bool Img::is_cached()
 {
@@ -157,7 +192,10 @@ const std::string Img::get_cache_path()
 //
 // receive_data()　と receive_finish() がコールバックされる
 //
-void Img::download_img( const std::string refurl )
+// refurl : 参照元のスレのアドレス
+// mosaic : モザイク表示するか
+//
+void Img::download_img( const std::string& refurl, const bool mosaic )
 {
     // ダウンロード初回(リダイレクトでは無い)
     if( ! m_count_redirect ) m_url_alt = std::string();
@@ -185,19 +223,14 @@ void Img::download_img( const std::string refurl )
 
     clear();
     m_refurl = refurl;
+    m_mosaic = mosaic;
                
     JDLIB::LOADERDATA data;
+    data.init_for_data();
 
     if( ! m_url_alt.empty() ) data.url = m_url_alt;
     else data.url = m_url;
 
-    data.agent = CONFIG::get_agent_for_data();
-    if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
-    else data.host_proxy = std::string();
-    data.port_proxy = CONFIG::get_proxy_port_for_data();
-    data.size_buf = CONFIG::get_loader_bufsize();
-    data.timeout = CONFIG::get_loader_timeout_img();
-
     if( !start_load( data ) ) receive_finish();
     else CORE::core_set_command( "redraw", m_url );
 }
@@ -233,7 +266,7 @@ const bool Img::save( Gtk::Window* parent, const std::string& path_to )
 //
 // モザイクon/off
 //
-void Img::set_mosaic( bool mosaic )
+void Img::set_mosaic( const bool mosaic )
 {
     if( ! is_cached() ) return;
 
@@ -382,10 +415,10 @@ void Img::receive_finish()
               << "contenttype = " << get_contenttype() << std::endl
               << "cookies : " << std::endl;
 
-    if( cookies().size() ){
-        std::list< std::string >::iterator it = cookies().begin();
-        for( ; it != cookies().end() ; ++it ) std::cout << *it << std::endl;
-    }
+//    if( cookies().size() ){
+//        std::list< std::string >::iterator it = cookies().begin();
+//        for( ; it != cookies().end() ; ++it ) std::cout << *it << std::endl;
+//    }
 #endif
 
     if( m_fout ) fclose( m_fout );
@@ -410,7 +443,7 @@ void Img::receive_finish()
 #endif
             ++m_count_redirect;
             m_url_alt = location();
-            download_img( m_refurl );
+            download_img( m_refurl, m_mosaic );
             return;
         }
         else m_type = T_NODATA;
@@ -424,7 +457,6 @@ void Img::receive_finish()
 
         MISC::get_img_size( get_cache_path(), m_width, m_height );
         if( ! m_width || ! m_height ) m_type = T_NOSIZE;
-        else set_embedded_size();
     }
 
 
@@ -504,6 +536,14 @@ void Img::receive_finish()
               << "refurl = " << m_refurl << std::endl;
 #endif
 
+    // 画像が小さい場合はモザイクを解除
+    if( m_width && m_height ){
+
+        const int minsize = MAX( 1, CONFIG::get_mosaic_size() );
+        if( m_width >= m_height && m_width < minsize ) m_mosaic = false;
+        else if( m_width < m_height && m_height < minsize ) m_mosaic = false;
+    }
+
     // 拡張子が偽装されている時はモザイク表示にする
     if( is_fake() ) m_mosaic = true;
 
@@ -526,9 +566,14 @@ void Img::set_embedded_size()
     double scale_w = ( double ) MAX_WIDTH_EMB / m_width;
     double scale_h = ( double ) MAX_HEIGHT_EMB / m_height;
     scale = MIN( scale_w, scale_h );
-
-    m_width_emb = (int)( m_width * scale );
-    m_height_emb = (int)( m_height * scale );
+    if( scale < 1.0 ){
+        m_width_emb = (int)( m_width * scale );
+        m_height_emb = (int)( m_height * scale );
+    }
+    else{
+        m_width_emb = m_width;
+        m_height_emb = m_height;
+    }
 
 #ifdef _DEBUG
     std::cout << "Img::set_embedded_size w = " << m_width_emb << " h = " << m_height_emb << std::endl;
@@ -536,6 +581,34 @@ void Img::set_embedded_size()
 }
 
 
+// モザイク処理時に縮小するサイズを経産
+void Img::set_mosaic_size()
+{
+    if( ! m_width || ! m_height ) return;
+
+    // 一旦元画像の横幅を mossize ピクセルまで縮めてから描画サイズに戻す
+    const int mossize = MAX( 1, CONFIG::get_mosaic_size() );
+    int moswidth = m_width;
+    int mosheight = m_height;
+
+    if( moswidth >= mosheight ){
+
+        const int dev = MAX( 1, moswidth / mossize );
+        mosheight /= dev;
+        moswidth = mossize;
+    }
+    else{
+
+        const int dev = MAX( 1, mosheight / mossize );
+        mosheight = mossize;
+        moswidth /= dev;
+    }
+
+    m_width_mosaic = MAX( 1, moswidth );
+    m_height_mosaic = MAX( 1, mosheight );
+}
+
+
 //
 // キャッシュ情報読み込み
 //
@@ -644,7 +717,6 @@ void Img::read_info()
             if( total_length() ) save_info();
         }
         set_current_length( total_length() );
-        set_embedded_size();
     }
 
 #ifdef _DEBUG
