@@ -122,6 +122,15 @@ SKELETON::Admin* MessageViewBase::get_admin()
 }
 
 
+//
+// 親ウィンドウを取得
+//
+Gtk::Window* MessageViewBase::get_parent_win()
+{
+    return MESSAGE::get_admin()->get_win();
+}
+
+
 //
 // コピー用URL( readcgi型 )
 //
@@ -133,7 +142,6 @@ const std::string MessageViewBase::url_for_copy()
 }
 
 
-
 void MessageViewBase::clock_in()
 {
     if( m_preview ) m_preview->clock_in();
@@ -252,7 +260,7 @@ const bool MessageViewBase::set_command( const std::string& command, const std::
                 SESSION::set_dir_draft( MISC::get_dir( save_to ) );
 
                 if( CACHE::save_rawdata( save_to, get_message() ) != get_message().raw().length() ){
-                    SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                    SKELETON::MsgDiag mdiag( get_parent_win(),
                                              "保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
                     mdiag.run();
                 }
@@ -433,6 +441,43 @@ const bool MessageViewBase::operate_view( const int control )
             MESSAGE::get_admin()->set_command( "tab_right" );
             break;
 
+        // タブ位置(1-9)で移動
+        case CONTROL::TabNum1:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "1" );
+            break;
+
+        case CONTROL::TabNum2:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "2" );
+            break;
+
+        case CONTROL::TabNum3:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "3" );
+            break;
+
+        case CONTROL::TabNum4:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "4" );
+            break;
+
+        case CONTROL::TabNum5:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "5" );
+            break;
+
+        case CONTROL::TabNum6:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "6" );
+            break;
+
+        case CONTROL::TabNum7:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "7" );
+            break;
+
+        case CONTROL::TabNum8:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "8" );
+            break;
+
+        case CONTROL::TabNum9:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "9" );
+            break;
+
             // 書き込みボタンにフォーカスを移す
         case CONTROL::FocusWrite:
             MESSAGE::get_admin()->set_command( "focus_button_write" );
@@ -460,13 +505,13 @@ void MessageViewBase::write()
     if( left
         && ! SESSION::loginbe() // BEログイン中はダイアログを表示しない
         ){
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
         mdiag.run();
         return;
     }
 
     if( m_post && m_post->is_loading() ){
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み中です" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "書き込み中です" );
         mdiag.run();
         return;
     }
@@ -479,7 +524,7 @@ void MessageViewBase::write()
 
         std::string name = get_entry_name().get_text();
         if( name.empty() ){
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "名前欄が空白です。fusianasan 書き込みになる可能性があります。" );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "名前欄が空白です。fusianasan 書き込みになる可能性があります。" );
             mdiag.run();
             return;
         }
@@ -490,7 +535,7 @@ void MessageViewBase::write()
     if( m_max_line ){
 
         if( m_text_message.get_buffer()->get_line_count() > m_max_line ){
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "行数が多すぎます。" );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "行数が多すぎます。" );
             mdiag.run();
             return;
         }
@@ -500,7 +545,7 @@ void MessageViewBase::write()
     if( m_max_str ){
 
         if( m_lng_str_enc > m_max_str ){
-            SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "文字数が多すぎます。" );
+            SKELETON::MsgDiag mdiag( get_parent_win(), "文字数が多すぎます。" );
             mdiag.run();
             return;
         }
@@ -515,10 +560,12 @@ void MessageViewBase::write()
 //
 void MessageViewBase::insert_draft()
 {
-    std::string open_path = CACHE::open_load_diag( MESSAGE::get_admin()->get_win(), SESSION::get_dir_draft(), CACHE::FILE_TYPE_TEXT );
+    const std::list< std::string > list_files = CACHE::open_load_diag( MESSAGE::get_admin()->get_win(),
+                                                                       SESSION::get_dir_draft(), CACHE::FILE_TYPE_TEXT, false );
 
-    if( ! open_path.empty() )
+    if( list_files.size() )
     {
+        const std::string open_path = *list_files.begin();
         std::string draft;
 
         SESSION::set_dir_draft( MISC::get_dir( open_path ) );
@@ -690,7 +737,7 @@ void MessageViewBase::post_fin()
     // タイムアウト
     else if( code == HTTP_TIMEOUT ){
 
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+        SKELETON::MsgDiag mdiag( get_parent_win(),
                                  "タイムアウトしました\n\n書き込み自体は成功している可能性があります。\nメッセージのバックアップをとってからスレを再読み込みして下さい。" );
         mdiag.run();
     }
@@ -698,7 +745,7 @@ void MessageViewBase::post_fin()
     // 失敗
     else if( code != HTTP_CANCEL ){
 
-        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+        SKELETON::MsgDiag mdiag( get_parent_win(),
                                  "書き込みに失敗しました\n\n" + m_post->errmsg(), false, Gtk::MESSAGE_ERROR  );
         mdiag.run();
     }
@@ -733,15 +780,16 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
         // 名前 + トリップ
         if( ! m_entry_name.get_text().empty() ){
 
-            std::string name = MISC::html_escape( m_entry_name.get_text() );
+            const std::string name_field = m_entry_name.get_text();
+
+            const size_t trip_pos = name_field.find( "#", 0 );
+
+            const std::string name = MISC::html_escape( name_field.substr( 0, trip_pos ) );
 
             std::string trip;
-
-	    std::string::size_type i = name.find( "#" );
-            if( i != std::string::npos ){
-
-                trip = MISC::get_trip( name.substr( i+1 ), DBTREE::board_charset( get_url() ) );
-                name = name.substr( 0, i );
+            if( trip_pos != std::string::npos )
+            {
+                trip = MISC::get_trip( name_field.substr( trip_pos + 1 ), DBTREE::board_charset( get_url() ) );
             }
 
             ss << name;
