@@ -7,10 +7,6 @@
 #include "cache.h"
 #include "global.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "jdlib/confloader.h"
 #include "jdlib/miscutil.h"
 
@@ -18,12 +14,6 @@
 #include "article/articleadmin.h"
 
 #include <sstream>
-#include <cstring>
-#include <vector>
-
-#ifdef HAVE_SYS_UTSNAME_H
-#include <sys/utsname.h> // uname()
-#endif
 
 bool booting = true;
 bool quitting = false;
@@ -34,10 +24,6 @@ bool mode_login2ch;
 bool mode_loginbe;
 bool mode_loginp2;
 
-std::string distribution_name;
-
-int win_manager;
-
 int win_hpane_main_pos;
 int win_vpane_main_pos;
 int win_hpane_main_r_pos;
@@ -142,7 +128,7 @@ bool embedded_img;
 bool embedded_mes;
 bool close_mes;
 
-std::string img_dir_dat_save;
+std::string dir_dat;
 std::string img_dir_img_save;
 
 std::string dir_draft;
@@ -164,8 +150,8 @@ std::string dir_select_favorite;
 std::vector< int > parse_items( const std::string& items_str )
 {
     std::vector< int > items;
-    std::list< std::string > list_order = MISC::split_line( items_str );
-    std::list< std::string >::iterator it = list_order.begin();
+    const std::list< std::string > list_order = MISC::split_line( items_str );
+    std::list< std::string >::const_iterator it = list_order.begin();
     for( ; it != list_order.end(); ++it ){
 
         if( *it == ITEM_NAME_BBSLISTVIEW ) items.push_back(ITEM_BBSLISTVIEW );
@@ -194,6 +180,7 @@ std::vector< int > parse_items( const std::string& items_str )
         if( *it == ITEM_NAME_STOPLOADING ) items.push_back( ITEM_STOPLOADING );
         if( *it == ITEM_NAME_FAVORITE ) items.push_back( ITEM_FAVORITE );
         if( *it == ITEM_NAME_CHECK_UPDATE_ROOT ) items.push_back( ITEM_CHECK_UPDATE_ROOT );
+        if( *it == ITEM_NAME_CHECK_UPDATE_OPEN_ROOT ) items.push_back( ITEM_CHECK_UPDATE_OPEN_ROOT );
         if( *it == ITEM_NAME_DELETE ) items.push_back( ITEM_DELETE );
         if( *it == ITEM_NAME_QUIT ) items.push_back( ITEM_QUIT );
         if( *it == ITEM_NAME_PREVVIEW ) items.push_back( ITEM_PREVVIEW );
@@ -229,7 +216,7 @@ void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const st
     std::list< std::string > list_tmp;
     std::list< std::string >::iterator it_tmp;
 
-    str_tmp = cf.get_option( id_urls, "");
+    str_tmp = cf.get_option_str( id_urls, "" );
     if( ! str_tmp.empty() ){
         list_tmp = MISC::split_line( str_tmp );
         it_tmp = list_tmp.begin();
@@ -238,7 +225,7 @@ void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const st
 
     if( ! list_urls.size() ) return;
 
-    str_tmp = cf.get_option( id_locked, "");
+    str_tmp = cf.get_option_str( id_locked, "" );
     if( ! str_tmp.empty() ){
         list_tmp = MISC::split_line( str_tmp );
         it_tmp = list_tmp.begin();
@@ -250,153 +237,6 @@ void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const st
 }
 
 
-// ファイル等からディストリ名を取得
-std::string get_distribution_name_from_environment()
-{
-#ifdef _DEBUG
-    std::cout << "SESSION::get_distribution_name_from_environment\n";
-#endif
-
-    std::string tmp;
-    std::string text_data;
-
-    // LSB系 ( Ubuntu ..etc )
-    if( CACHE::load_rawdata( "/etc/lsb-release", text_data ) )
-    {
-        std::list< std::string > lines = MISC::get_lines( text_data );
-        std::list< std::string >::reverse_iterator it = lines.rbegin();
-        while( it != lines.rend() )
-        {
-            std::string lsb_name, lsb_data;
-
-            size_t e;
-            if( ( e = (*it).find( "=" ) ) != std::string::npos )
-            {
-                lsb_name = MISC::remove_spaces( (*it).substr( 0, e ) );
-                lsb_data = MISC::remove_spaces( (*it).substr( e + 1 ) );
-            }
-
-            // 「DISTRIB_DESCRIPTION="Ubuntu 7.10"」などから「Ubuntu 7.10」を取得
-            if( lsb_name == "DISTRIB_DESCRIPTION" && ! lsb_data.empty() )
-            {
-                tmp = MISC::cut_str( lsb_data, "\"", "\"" );
-                break;
-            }
-
-            ++it;
-        }
-    }
-    // KNOPPIX (LSB？)
-    else if( CACHE::load_rawdata( "/etc/knoppix-version", text_data ) )
-    {
-        tmp = "KNOPPIX ";
-        tmp.append( text_data );
-    }
-    // Debian
-    else if( CACHE::load_rawdata( "/etc/debian_version", text_data ) )
-    {
-        tmp = "Debian GNU/Linux ";
-        tmp.append( text_data );
-    }
-    // Solaris系
-    else if( CACHE::load_rawdata( "/etc/release", text_data ) )
-    {
-        std::list< std::string > lines = MISC::get_lines( text_data );
-        std::list< std::string >::iterator it = lines.begin();
-        while( it != lines.end() )
-        {
-            // 名前が含まれている行を取得
-            if( (*it).find( "BeleniX" ) != std::string::npos
-                || (*it).find( "Nexenta" ) != std::string::npos
-                || (*it).find( "SchilliX" ) != std::string::npos
-                || (*it).find( "Solaris" ) != std::string::npos )
-            {
-                tmp = *it;
-                break;
-            }
-
-            ++it;
-        }
-    }
-    // ファイルの中身がそのままディストリ名として扱える物
-    else
-    {
-        // ディストリ名が書かれているファイル
-        std::string dist_files[] =
-        {
-            "/etc/arch-release",
-            "/etc/fedora-release",
-            "/etc/gentoo-release",
-            "/etc/lfs-release",
-            "/etc/mandriva-release",
-            "/etc/momonga-release",
-            "/usr/lib/setup/plamo-version",
-            "/etc/puppyversion",
-            "/etc/redhat-release", // Redhat, CentOS, WhiteBox, PCLinuxOS
-            "/etc/sabayon-release",
-            "/etc/slackware-version",
-            "/etc/SuSE-release",
-            "/etc/turbolinux-release",
-            "/etc/vine-release",
-            "/etc/zenwalk-version"
-        };
-
-        unsigned int i;
-        for( i = 0; i < sizeof( dist_files ) / sizeof( std::string ); ++i )
-        {
-            if( CACHE::load_rawdata( dist_files[i], text_data ) )
-            {
-                tmp = text_data;
-                break;
-            }
-        }
-    }
-
-    // 文字列両端のスペースなどを削除する
-    std::string dist_name = MISC::remove_spaces( tmp );
-
-    // 取得した文字が異常に長い場合は空にする
-    if( dist_name.length() > 50 ) dist_name.clear();
-
-#ifdef HAVE_SYS_UTSNAME_H
-
-    char *sysname = 0, *release = 0, *machine = 0;
-
-    // システムコール uname() 準拠：SVr4, POSIX.1-2001.
-    struct utsname* uts;
-    uts = (struct utsname*)malloc( sizeof( struct utsname ) );
-    if( uname( uts ) != -1 )
-    {
-        sysname = uts->sysname;
-        release = uts->release;
-        machine = uts->machine;
-    }
-
-    // FreeBSD等やディストリ名が取得できなかった場合は"$ uname -rs"と同じ様式
-    if( dist_name.empty() && sysname && release )
-    {
-        dist_name = std::string( sysname ) + " " + std::string( release );
-    }
-
-    // アーキテクチャがx86でない場合
-    if( machine &&
-        ( strlen( machine ) != 4
-          || ! ( machine[0] == 'i'
-               && machine[1] >= '3' && machine[1] <= '6'
-               && machine[2] == '8' && machine[3] == '6' ) ) )
-    {
-        dist_name.append( " (" + std::string( machine ) + ")" );
-    }
-
-    free( uts );
-    uts = NULL;
-
-#endif
-
-    return dist_name;
-}
-
-
 // セッション情報読み込み
 void SESSION::init_session()
 {
@@ -407,66 +247,69 @@ void SESSION::init_session()
     JDLIB::ConfLoader cf( CACHE::path_session(), std::string() );
 
     // オンライン
-    mode_online = cf.get_option( "mode_online", true );
+    mode_online = cf.get_option_bool( "mode_online", true );
 
     // 2chログイン
-    mode_login2ch = cf.get_option( "mode_login2ch", false );
+    mode_login2ch = cf.get_option_bool( "mode_login2ch", false );
 
     // beログイン
-    mode_loginbe = cf.get_option( "mode_loginbe", false );
+    mode_loginbe = cf.get_option_bool( "mode_loginbe", false );
 
     // p2ログイン
-    mode_loginp2 = cf.get_option( "mode_loginp2", false );
+    mode_loginp2 = cf.get_option_bool( "mode_loginp2", false );
 
     // paneのモード
-    mode_pane = cf.get_option( "mode_pane", 0 );
+    mode_pane = cf.get_option_int( "mode_pane", MODE_2PANE, 0, MODE_PANE_NUM -1 );
 
-    x_win_main = cf.get_option( "x", 0 );
-    y_win_main = cf.get_option( "y", 0 );
-    width_win_main = cf.get_option( "width", 800 );
-    height_win_main = cf.get_option( "height", 600 );
-    maximized_win_main = cf.get_option( "maximized", false );
+    x_win_main = cf.get_option_int( "x", 0, 0, 8192 );
+    y_win_main = cf.get_option_int( "y", 0, 0, 8192 );
+    width_win_main = cf.get_option_int( "width", 800, 80, 8192 );
+    height_win_main = cf.get_option_int( "height", 600, 60, 8192 );
+    maximized_win_main = cf.get_option_bool( "maximized", false );
 
-    win_show_sidebar = cf.get_option( "show_sidebar", true );
+    win_show_sidebar = cf.get_option_bool( "show_sidebar", true );
 
-    win_show_menubar = cf.get_option( "show_menubar", true );
+    win_show_menubar = cf.get_option_bool( "show_menubar", true );
 
-    win_toolbar_pos = cf.get_option( "toolbar_pos", 0 );
+    win_toolbar_pos = cf.get_option_int( "toolbar_pos", TOOLBAR_POS_NORMAL, 0, TOOLBAR_POS_NUM -1 );
 
-    show_bbslist_toolbar = cf.get_option( "show_bbslist_toolbar", true );
-    show_board_toolbar = cf.get_option( "show_board_toolbar", true );
-    show_article_toolbar = cf.get_option( "show_article_toolbar", true );
+    show_bbslist_toolbar = cf.get_option_bool( "show_bbslist_toolbar", true );
+    show_board_toolbar = cf.get_option_bool( "show_board_toolbar", true );
+    show_article_toolbar = cf.get_option_bool( "show_article_toolbar", true );
 
-    show_board_tab = cf.get_option( "show_board_tab", true );
-    show_article_tab = cf.get_option( "show_article_tab", true );
+    show_board_tab = cf.get_option_bool( "show_board_tab", true );
+    show_article_tab = cf.get_option_bool( "show_article_tab", true );
 
-    win_focused_admin = cf.get_option( "focused_admin", FOCUS_NO );
-    win_focused_admin_sidebar = cf.get_option( "focused_admin_sidebar", FOCUS_NO );
+    win_focused_admin = cf.get_option_int( "focused_admin", FOCUS_NOT, 0, FOCUS_NUM -1 );
+    win_focused_admin_sidebar = cf.get_option_int( "focused_admin_sidebar", FOCUS_NOT, 0, FOCUS_NUM -1 );
 
-    win_hpane_main_pos = cf.get_option( "hpane_main_pos", 190 );
-    win_vpane_main_pos = cf.get_option( "vpane_main_pos", 200 );
-    win_hpane_main_r_pos = cf.get_option( "hpane_main_r_pos", 300 );
-    win_vpane_main_mes_pos = cf.get_option( "vpane_main_mes_pos", 400 );
+    win_hpane_main_pos = cf.get_option_int( "hpane_main_pos", 190, 0, 8192 );
+    win_vpane_main_pos = cf.get_option_int( "vpane_main_pos", 200, 0, 8192 );
+    win_hpane_main_r_pos = cf.get_option_int( "hpane_main_r_pos", 300, 0, 8192 );
+    win_vpane_main_mes_pos = cf.get_option_int( "vpane_main_mes_pos", 400, 0, 8192 );
 
-    win_notebook_main_page = cf.get_option( "notebook_main_page", 0 );
+    // メインnotebookのページ番号
+    win_notebook_main_page = cf.get_option_int( "notebook_main_page", PAGE_ARTICLE, 0, PAGE_NUM -1 );
 
-    win_bbslist_page = cf.get_option( "bbslist_page", 0 );
-    win_board_page = cf.get_option( "board_page", 0 );
-    win_article_page = cf.get_option( "article_page", 0 );
-    win_image_page = cf.get_option( "image_page", 0 );
+    // 各ビューの開いてるページ番号
+    win_bbslist_page = cf.get_option_int( "bbslist_page", 0, 0, 1024 );
+    win_board_page = cf.get_option_int( "board_page", 0, 0, 1024 );
+    win_article_page = cf.get_option_int( "article_page", 0, 0, 1024 );
+    win_image_page = cf.get_option_int( "image_page", 0, 0, 1024 );
 
+    // タブをロックしているページのアドレス
     read_list_urls( cf, "board_urls", "board_locked", board_urls, board_locked );
     read_list_urls( cf, "article_urls", "article_locked", article_urls, article_locked );
     read_list_urls( cf, "image_urls", "image_locked", image_urls, image_locked );
 
-    items_sidebar_str = cf.get_option( "items_sidebar",
+    items_sidebar_str = cf.get_option_str( "items_sidebar",
                                  ITEM_NAME_SEARCHBOX + std::string ( " " ) +
                                  ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
                                  ITEM_NAME_SEARCH_PREV + std::string ( " " ) );
 
     items_sidebar =  parse_items( items_sidebar_str );
 
-    items_main_toolbar_str = cf.get_option( "items_main_toolbar",
+    items_main_toolbar_str = cf.get_option_str( "items_main_toolbar",
                                  ITEM_NAME_BBSLISTVIEW + std::string ( " " ) +
                                  ITEM_NAME_FAVORITEVIEW + std::string ( " " ) +
                                  ITEM_NAME_BOARDVIEW + std::string ( " " ) +
@@ -478,7 +321,7 @@ void SESSION::init_session()
 
     items_main_toolbar =  parse_items( items_main_toolbar_str );
 
-    items_article_toolbar_str = cf.get_option( "items_article_toolbar",
+    items_article_toolbar_str = cf.get_option_str( "items_article_toolbar",
                                  ITEM_NAME_WRITEMSG + std::string ( " " ) +
                                  ITEM_NAME_OPENBOARD + std::string ( " " ) +
                                  ITEM_NAME_NAME + std::string ( " " ) +
@@ -491,7 +334,7 @@ void SESSION::init_session()
 
     items_article_toolbar =  parse_items( items_article_toolbar_str );
 
-    items_board_toolbar_str = cf.get_option( "items_board_toolbar",
+    items_board_toolbar_str = cf.get_option_str( "items_board_toolbar",
                                  ITEM_NAME_NEWARTICLE + std::string ( " " ) +
                                  ITEM_NAME_SEARCHBOX + std::string ( " " ) +
                                  ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
@@ -504,7 +347,7 @@ void SESSION::init_session()
 
     items_board_toolbar =  parse_items( items_board_toolbar_str );
 
-    items_board_str = cf.get_option( "items_board",
+    items_board_str = cf.get_option_str( "items_board",
                                  ITEM_NAME_MARK + std::string ( " " ) +
                                  ITEM_NAME_ID + std::string ( " " ) +
                                  ITEM_NAME_NAME + std::string ( " " ) +
@@ -517,7 +360,7 @@ void SESSION::init_session()
 
     items_board =  parse_items( items_board_str );
 
-    items_msg_toolbar_str = cf.get_option( "items_msg_toolbar",
+    items_msg_toolbar_str = cf.get_option_str( "items_msg_toolbar",
                                  ITEM_NAME_PREVIEW + std::string ( " " ) +
                                  ITEM_NAME_WRITEMSG+ std::string ( " " ) +
                                  ITEM_NAME_NAME + std::string ( " " ) +
@@ -528,59 +371,45 @@ void SESSION::init_session()
 
     items_msg_toolbar =  parse_items( items_msg_toolbar_str );
 
-    board_col_mark = cf.get_option( "col_mark", 30 );
-    board_col_id = cf.get_option( "col_id", 45 );
-    board_col_subject = cf.get_option(  "col_subject", 190 );
-    board_col_number = cf.get_option( "col_number", 45 );
-    board_col_load = cf.get_option( "col_load", 45 );
-    board_col_new = cf.get_option( "col_new", 45 );
-    board_col_since = cf.get_option( "col_since", 70 );
-    board_col_write = cf.get_option( "col_write", 70 );
-    board_col_speed = cf.get_option( "col_speed", 45 );
+    // board ビューの列幅
+    board_col_mark = cf.get_option_int( "col_mark", 30, 4, 8192 );
+    board_col_id = cf.get_option_int( "col_id", 45, 4, 8192 );
+    board_col_subject = cf.get_option_int( "col_subject", 190, 4, 8192 );
+    board_col_number = cf.get_option_int( "col_number", 45, 4, 8192 );
+    board_col_load = cf.get_option_int( "col_load", 45, 4, 8192 );
+    board_col_new = cf.get_option_int( "col_new", 45, 4, 8192 );
+    board_col_since = cf.get_option_int( "col_since", 70, 4, 8192 );
+    board_col_write = cf.get_option_int( "col_write", 70, 4, 8192 );
+    board_col_speed = cf.get_option_int( "col_speed", 45, 4, 8192 );
 
-    embedded_img = cf.get_option( "embedded_img", true );
+    embedded_img = cf.get_option_bool( "embedded_img", true );
 
-    x_win_img = cf.get_option( "x_win_img", 0 );
-    y_win_img = cf.get_option( "y_win_img", 0 );
-    width_win_img = cf.get_option( "width_win_img", 600 );
-    height_win_img = cf.get_option( "height_win_img", 400 );
+    x_win_img = cf.get_option_int( "x_win_img", 0, 0, 8192 );
+    y_win_img = cf.get_option_int( "y_win_img", 0, 0, 8192 );
+    width_win_img = cf.get_option_int( "width_win_img", 600, 60, 8192 );
+    height_win_img = cf.get_option_int( "height_win_img", 400, 40, 8192 );
 
-    embedded_mes = cf.get_option( "embedded_mes", false );
-    close_mes = cf.get_option( "close_mes", true );
+    embedded_mes = cf.get_option_bool( "embedded_mes", false );
 
-    x_win_mes = cf.get_option( "x_win_mes", 0 );
-    y_win_mes = cf.get_option( "y_win_mes", 0 );
-    width_win_mes = cf.get_option( "width_win_mes", 600 );
-    height_win_mes = cf.get_option( "height_win_mes", 400 );
+    // 書き込み後にmessageを閉じる
+    close_mes = cf.get_option_bool( "close_mes", true );
 
-    img_dir_dat_save = cf.get_option( "img_dir_dat_save", "" );
-    img_dir_img_save = cf.get_option( "img_dir_img_save", "" );
+    x_win_mes = cf.get_option_int( "x_win_mes", 0, 0, 8192 );
+    y_win_mes = cf.get_option_int( "y_win_mes", 0, 0, 8192 );
+    width_win_mes = cf.get_option_int( "width_win_mes", 600, 60, 8192 );
+    height_win_mes = cf.get_option_int( "height_win_mes", 400, 40, 8192 );
 
-    dir_draft = cf.get_option( "dir_draft", "" );
+    dir_dat = cf.get_option_str( "dir_dat", "" );
+    img_dir_img_save = cf.get_option_str( "img_dir_img_save", "" );
+
+    dir_draft = cf.get_option_str( "dir_draft", "" );
 
     popupmenu_shown = false;
 
-    img_fit_mode = cf.get_option( "img_fit_mode", IMG_FIT_NORMAL );
+    // 画像のfitモード
+    img_fit_mode = cf.get_option_int( "img_fit_mode", IMG_FIT_NORMAL, 0, IMG_FIT_NUM -1 );
 
-    dir_select_favorite = cf.get_option( "dir_select_favorite", "" );
-
-    // WM 判定
-    // TODO: 環境変数で判定できない場合の判定方法を考える
-    win_manager = WM_UNKNON;
-    const std::string str_wm = MISC::getenv_limited( "DESKTOP_SESSION", 5 );
-
-    if( str_wm.find( "xfce" ) != std::string::npos ) win_manager = WM_XFCE;
-    else if( str_wm.find( "gnome" ) != std::string::npos ) win_manager = WM_GNOME;
-    else if( str_wm.find( "kde" ) != std::string::npos ) win_manager = WM_KDE;
-
-    if( win_manager == WM_UNKNON ){
-        if( ! MISC::getenv_limited( "GNOME_DESKTOP_SESSION_ID" ).empty() ) win_manager = WM_GNOME;
-        else{
-
-            const std::string str_wm = MISC::getenv_limited( "KDE_FULL_SESSION", 4 );
-            if( str_wm == "true" ) win_manager = WM_KDE;
-        }
-    }
+    dir_select_favorite = cf.get_option_str( "dir_select_favorite", "" );
 
 #ifdef _DEBUG
     std::cout << "x=" << x_win_main << std::endl
@@ -607,7 +436,8 @@ void SESSION::init_session()
               << "image_page=" << win_image_page << std::endl;
 
     std::cout << "board_urls\n";
-    it_tmp = board_urls.begin();
+
+    std::list< std::string >::iterator it_tmp = board_urls.begin();
     for( ; it_tmp != board_urls.end(); ++it_tmp ) if( !(*it_tmp).empty() ) std::cout << (*it_tmp);
 
     std::cout << "article_urls\n";
@@ -760,7 +590,7 @@ void SESSION::save_session()
         << "width_win_mes = " << width_win_mes << std::endl
         << "height_win_mes = " << height_win_mes << std::endl
 
-        << "img_dir_dat_save = " << img_dir_dat_save << std::endl
+        << "dir_dat = " << dir_dat << std::endl
         << "img_dir_img_save = " << img_dir_img_save << std::endl
         << "dir_draft = " << dir_draft << std::endl
 
@@ -778,27 +608,17 @@ void SESSION::save_session()
 
 // ブート中
 const bool SESSION::is_booting(){ return booting; }
-void SESSION::set_booting( bool boot ){ booting = boot; }
+void SESSION::set_booting( const bool boot ){ booting = boot; }
 
 // 終了中
 const bool SESSION::is_quitting(){ return quitting; }
-void SESSION::set_quitting( bool quit ){ quitting = quit; }
-
-// ディストリ名取得
-const std::string& SESSION::get_distribution_name()
-{
-    if( distribution_name.empty() ) distribution_name = get_distribution_name_from_environment();
-    return distribution_name;
-}
-
-// WM 判定
-const int SESSION::get_wm(){ return win_manager; }
+void SESSION::set_quitting( const bool quit ){ quitting = quit; }
 
 const int SESSION::get_mode_pane() { return mode_pane; }
-void SESSION::set_mode_pane( int mode ){ mode_pane = mode; }
+void SESSION::set_mode_pane( const int mode ){ mode_pane = mode; }
 
 const bool SESSION::is_online(){ return mode_online; }
-void SESSION::set_online( bool mode ){ mode_online = mode; }
+void SESSION::set_online( const bool mode ){ mode_online = mode; }
 
 const bool SESSION::login2ch(){ return mode_login2ch; }
 void SESSION::set_login2ch( const bool login ){ mode_login2ch = login; }
@@ -812,141 +632,141 @@ void SESSION::set_loginp2( const bool login ){ mode_loginp2 = login; }
 const bool SESSION::show_sidebar(){ return win_show_sidebar; }
 
 const bool SESSION::show_menubar(){ return win_show_menubar; }
-void SESSION::set_show_menubar( bool show ){ win_show_menubar = show; }
+void SESSION::set_show_menubar( const bool show ){ win_show_menubar = show; }
 
 const int SESSION::toolbar_pos(){ return win_toolbar_pos; }
-void SESSION::set_toolbar_pos( int pos ){ win_toolbar_pos = pos; }
+void SESSION::set_toolbar_pos( const int pos ){ win_toolbar_pos = pos; }
 
 const bool SESSION::get_show_bbslist_toolbar(){ return show_bbslist_toolbar; }
-void SESSION::set_show_bbslist_toolbar( bool show ){ show_bbslist_toolbar = show; }
+void SESSION::set_show_bbslist_toolbar( const bool show ){ show_bbslist_toolbar = show; }
 
 const bool SESSION::get_show_board_toolbar(){ return show_board_toolbar; }
-void SESSION::set_show_board_toolbar( bool show ){ show_board_toolbar = show; }
+void SESSION::set_show_board_toolbar( const bool show ){ show_board_toolbar = show; }
 
 const bool SESSION::get_show_article_toolbar(){ return show_article_toolbar; }
-void SESSION::set_show_article_toolbar( bool show ){ show_article_toolbar = show; }
+void SESSION::set_show_article_toolbar( const bool show ){ show_article_toolbar = show; }
 
 const bool SESSION::get_show_board_tab(){ return show_board_tab; }
-void SESSION::set_show_board_tab( bool show ){ show_board_tab = show; }
+void SESSION::set_show_board_tab( const bool show ){ show_board_tab = show; }
 
 const bool SESSION::get_show_article_tab(){ return show_article_tab; }
-void SESSION::set_show_article_tab( bool show ){ show_article_tab = show; }
+void SESSION::set_show_article_tab( const bool show ){ show_article_tab = show; }
 
 const int SESSION::focused_admin(){ return win_focused_admin; }
-void SESSION::set_focused_admin( int admin ){ win_focused_admin = admin; }
-int SESSION::focused_admin_sidebar(){ return win_focused_admin_sidebar; }
-void SESSION::set_focused_admin_sidebar( int admin ){ win_focused_admin_sidebar = admin; }
+void SESSION::set_focused_admin( const int admin ){ win_focused_admin = admin; }
+const int SESSION::focused_admin_sidebar(){ return win_focused_admin_sidebar; }
+void SESSION::set_focused_admin_sidebar( const int admin ){ win_focused_admin_sidebar = admin; }
 
 
 // 各windowの座標
 const int SESSION::get_x_win_main(){ return x_win_main; }
 const int SESSION::get_y_win_main(){ return y_win_main; }
-void SESSION::set_x_win_main( int x ){ x_win_main = x; }
-void SESSION::set_y_win_main( int y ){ y_win_main = y; }
+void SESSION::set_x_win_main( const int x ){ x_win_main = x; }
+void SESSION::set_y_win_main( const int y ){ y_win_main = y; }
 
 const int SESSION::get_x_win_img(){ return x_win_img; }
 const int SESSION::get_y_win_img(){ return y_win_img; }
-void SESSION::set_x_win_img( int x ){ x_win_img = x; }
-void SESSION::set_y_win_img( int y ){ y_win_img = y; }
+void SESSION::set_x_win_img( const int x ){ x_win_img = x; }
+void SESSION::set_y_win_img( const int y ){ y_win_img = y; }
 
 const int SESSION::get_x_win_mes(){ return x_win_mes; }
 const int SESSION::get_y_win_mes(){ return y_win_mes; }
-void SESSION::set_x_win_mes( int x ){ x_win_mes = x; }
-void SESSION::set_y_win_mes( int y ){ y_win_mes = y; }
+void SESSION::set_x_win_mes( const int x ){ x_win_mes = x; }
+void SESSION::set_y_win_mes( const int y ){ y_win_mes = y; }
 
 
 // 各windowのサイズ
 const int SESSION::get_width_win_main(){ return width_win_main; }
 const int SESSION::get_height_win_main(){ return height_win_main; }
-void SESSION::set_width_win_main( int width ){ width_win_main = width; }
-void SESSION::set_height_win_main( int height ){ height_win_main = height; }
+void SESSION::set_width_win_main( const int width ){ width_win_main = width; }
+void SESSION::set_height_win_main( const int height ){ height_win_main = height; }
 
 const int SESSION::get_width_win_img(){ return width_win_img; }
 const int SESSION::get_height_win_img(){ return height_win_img; }
-void SESSION::set_width_win_img( int width ){ width_win_img = width; }
-void SESSION::set_height_win_img( int height ){ height_win_img = height; }
+void SESSION::set_width_win_img( const int width ){ width_win_img = width; }
+void SESSION::set_height_win_img( const int height ){ height_win_img = height; }
 
 const int SESSION::get_width_win_mes(){ return width_win_mes; }
 const int SESSION::get_height_win_mes(){ return height_win_mes; }
-void SESSION::set_width_win_mes( int width ){ width_win_mes = width; }
-void SESSION::set_height_win_mes( int height ){ height_win_mes = height; }
+void SESSION::set_width_win_mes( const int width ){ width_win_mes = width; }
+void SESSION::set_height_win_mes( const int height ){ height_win_mes = height; }
 
 
 // 各window がフォーカスされているか
 const bool SESSION::is_focus_win_main(){ return focus_win_main; }
-void SESSION::set_focus_win_main( bool set ){ focus_win_main = set; }
+void SESSION::set_focus_win_main( const bool set ){ focus_win_main = set; }
 
 const bool SESSION::is_focus_win_img(){ return focus_win_img; }
-void SESSION::set_focus_win_img( bool set ){ focus_win_img = set; }
+void SESSION::set_focus_win_img( const bool set ){ focus_win_img = set; }
 
 const bool SESSION::is_focus_win_mes(){ return focus_win_mes; }
-void SESSION::set_focus_win_mes( bool set ){ focus_win_mes = set; }
+void SESSION::set_focus_win_mes( const bool set ){ focus_win_mes = set; }
 
 
 // 各window が最大化されているか
 const bool SESSION::is_maximized_win_main(){ return maximized_win_main; }
-void SESSION::set_maximized_win_main( bool set ){ maximized_win_main = set; }
+void SESSION::set_maximized_win_main( const bool set ){ maximized_win_main = set; }
 
 const bool SESSION::is_maximized_win_img(){ return maximized_win_img; }
-void SESSION::set_maximized_win_img( bool set ){ maximized_win_img = set; }
+void SESSION::set_maximized_win_img( const bool set ){ maximized_win_img = set; }
 
 bool SESSION::is_maximized_win_mes(){ return maximized_win_mes; }
-void SESSION::set_maximized_win_mes( bool set ){ maximized_win_mes = set; }
+void SESSION::set_maximized_win_mes( const bool set ){ maximized_win_mes = set; }
 
 
 // 各window が最小化されているか
 const bool SESSION::is_iconified_win_main(){ return iconified_win_main; }
-void SESSION::set_iconified_win_main( bool set ){ iconified_win_main = set; }
+void SESSION::set_iconified_win_main( const bool set ){ iconified_win_main = set; }
 
 const bool SESSION::is_iconified_win_img(){ return iconified_win_img; }
-void SESSION::set_iconified_win_img( bool set ){ iconified_win_img = set; }
+void SESSION::set_iconified_win_img( const bool set ){ iconified_win_img = set; }
 
 const bool SESSION::is_iconified_win_mes(){ return iconified_win_mes; }
-void SESSION::set_iconified_win_mes( bool set ){ iconified_win_mes = set; }
+void SESSION::set_iconified_win_mes( const bool set ){ iconified_win_mes = set; }
 
 
 // 各window が画面に表示されているか
 const bool SESSION::is_shown_win_main(){ return shown_win_main; }
-void SESSION::set_shown_win_main( bool set ){ shown_win_main = set; }
+void SESSION::set_shown_win_main( const bool set ){ shown_win_main = set; }
 
 const bool SESSION::is_shown_win_img(){ return shown_win_img; }
-void SESSION::set_shown_win_img( bool set ){ shown_win_img = set; }
+void SESSION::set_shown_win_img( const bool set ){ shown_win_img = set; }
 
 const bool SESSION::is_shown_win_mes(){ return shown_win_mes; }
-void SESSION::set_shown_win_mes( bool set ){ shown_win_mes = set; }
+void SESSION::set_shown_win_mes( const bool set ){ shown_win_mes = set; }
 
 
 // ダイアログ表示中
 const bool SESSION::is_dialog_shown(){ return dialog_shown; }
-void SESSION::set_dialog_shown( bool set ){ dialog_shown = set; }
+void SESSION::set_dialog_shown( const bool set ){ dialog_shown = set; }
 
-void SESSION::set_show_sidebar( bool showurl ){ win_show_sidebar = showurl; }
+void SESSION::set_show_sidebar( const bool showurl ){ win_show_sidebar = showurl; }
 
 
 // メインウィンドウのペインの敷居の位置
-int SESSION::hpane_main_pos(){ return win_hpane_main_pos; }
-int SESSION::vpane_main_pos(){ return win_vpane_main_pos; }
-int SESSION::hpane_main_r_pos(){ return win_hpane_main_r_pos; }
-int SESSION::vpane_main_mes_pos(){ return win_vpane_main_mes_pos; }
+const int SESSION::hpane_main_pos(){ return win_hpane_main_pos; }
+const int SESSION::vpane_main_pos(){ return win_vpane_main_pos; }
+const int SESSION::hpane_main_r_pos(){ return win_hpane_main_r_pos; }
+const int SESSION::vpane_main_mes_pos(){ return win_vpane_main_mes_pos; }
 
-void SESSION::set_hpane_main_pos( int pos ){ win_hpane_main_pos = pos; }
-void SESSION::set_vpane_main_pos( int pos ){ win_vpane_main_pos = pos; }
-void SESSION::set_hpane_main_r_pos( int pos ){ win_hpane_main_r_pos = pos; }
-void SESSION::set_vpane_main_mes_pos( int pos ){ win_vpane_main_mes_pos = pos; }
+void SESSION::set_hpane_main_pos( const int pos ){ win_hpane_main_pos = pos; }
+void SESSION::set_vpane_main_pos( const int pos ){ win_vpane_main_pos = pos; }
+void SESSION::set_hpane_main_r_pos( const int pos ){ win_hpane_main_r_pos = pos; }
+void SESSION::set_vpane_main_mes_pos( const int pos ){ win_vpane_main_mes_pos = pos; }
 
 // メインnotebookのページ番号
-int SESSION::notebook_main_page(){ return win_notebook_main_page; }
-void SESSION::set_notebook_main_page( int page ){ win_notebook_main_page = page; }
+const int SESSION::notebook_main_page(){ return win_notebook_main_page; }
+void SESSION::set_notebook_main_page( const int page ){ win_notebook_main_page = page; }
 
 // bbslistの開いてるページ番号
-int SESSION::bbslist_page(){ return win_bbslist_page; }
-void SESSION::set_bbslist_page( int page ){ win_bbslist_page = page; }
+const int SESSION::bbslist_page(){ return win_bbslist_page; }
+void SESSION::set_bbslist_page( const int page ){ win_bbslist_page = page; }
 
 
 // 前回閉じたときに開いていたboardのページ番号とURL
-int SESSION::board_page(){ return win_board_page; }
-void SESSION::set_board_page( int page ){ win_board_page = page; }
-std::list< std::string >& SESSION::get_board_URLs(){ return board_urls; }
+const int SESSION::board_page(){ return win_board_page; }
+void SESSION::set_board_page( const int page ){ win_board_page = page; }
+const std::list< std::string >& SESSION::get_board_URLs(){ return board_urls; }
 void SESSION::set_board_URLs( const std::list< std::string >& urls ){ board_urls = urls; }
 
 // スレ一覧のロック状態
@@ -954,9 +774,9 @@ const std::list< bool >& SESSION::get_board_locked(){ return board_locked; }
 void SESSION::set_board_locked( const std::list< bool >& locked ){ board_locked = locked; }
 
 // 前回閉じたときに開いていたスレタブのページ番号とURL
-int SESSION::article_page(){ return win_article_page; }
-void SESSION::set_article_page( int page ){ win_article_page = page; }
-std::list< std::string >& SESSION::get_article_URLs(){ return article_urls; }
+const int SESSION::article_page(){ return win_article_page; }
+void SESSION::set_article_page( const int page ){ win_article_page = page; }
+const std::list< std::string >& SESSION::get_article_URLs(){ return article_urls; }
 void SESSION::set_article_URLs( const std::list< std::string >& urls ){ article_urls = urls; }
 
 // スレタブのロック状態
@@ -964,8 +784,8 @@ const std::list< bool >& SESSION::get_article_locked(){ return article_locked; }
 void SESSION::set_article_locked( const std::list< bool >& locked ){ article_locked = locked; }
 
 // 前回閉じたときに開いていたimageのページ番号とURL
-int SESSION::image_page(){ return win_image_page; }
-void SESSION::set_image_page( int page ){ win_image_page = page; }
+const int SESSION::image_page(){ return win_image_page; }
+void SESSION::set_image_page( const int page ){ win_image_page = page; }
 const std::list< std::string >& SESSION::image_URLs(){ return image_urls; }
 void SESSION::set_image_URLs( const std::list< std::string >& urls ){ image_urls = urls; }
 
@@ -1029,15 +849,15 @@ const int SESSION::get_item_msg_toolbar( const int num ){ return items_msg_toolb
 
 
 // board ビューの列幅
-int SESSION::col_mark(){ return board_col_mark; }
-int SESSION::col_id(){ return board_col_id; }
-int SESSION::col_subject(){ return board_col_subject; }
-int SESSION::col_number(){ return board_col_number; }
-int SESSION::col_load(){ return board_col_load; }
-int SESSION::col_new(){ return board_col_new; }
-int SESSION::col_since(){ return board_col_since; }
-int SESSION::col_write(){ return board_col_write; }
-int SESSION::col_speed(){ return board_col_speed; }
+const int SESSION::col_mark(){ return board_col_mark; }
+const int SESSION::col_id(){ return board_col_id; }
+const int SESSION::col_subject(){ return board_col_subject; }
+const int SESSION::col_number(){ return board_col_number; }
+const int SESSION::col_load(){ return board_col_load; }
+const int SESSION::col_new(){ return board_col_new; }
+const int SESSION::col_since(){ return board_col_since; }
+const int SESSION::col_write(){ return board_col_write; }
+const int SESSION::col_speed(){ return board_col_speed; }
 
 
 // 現在開いている bbslist のページ
@@ -1053,15 +873,15 @@ const std::string SESSION::get_bbslist_current_url()
 }
 
 
-void SESSION::set_col_mark( int width ){ board_col_mark = width; }
-void SESSION::set_col_id( int width ){ board_col_id = width; }
-void SESSION::set_col_subject( int width ){ board_col_subject = width; }
-void SESSION::set_col_number( int width ){ board_col_number = width; }
-void SESSION::set_col_load( int width ){ board_col_load = width; }
-void SESSION::set_col_new( int width ){ board_col_new = width; }
-void SESSION::set_col_since( int width ){ board_col_since = width; }
-void SESSION::set_col_write( int width ){ board_col_write = width; }
-void SESSION::set_col_speed( int width ){ board_col_speed = width; }
+void SESSION::set_col_mark( const int width ){ board_col_mark = width; }
+void SESSION::set_col_id( const int width ){ board_col_id = width; }
+void SESSION::set_col_subject( const int width ){ board_col_subject = width; }
+void SESSION::set_col_number( const int width ){ board_col_number = width; }
+void SESSION::set_col_load( const int width ){ board_col_load = width; }
+void SESSION::set_col_new( const int width ){ board_col_new = width; }
+void SESSION::set_col_since( const int width ){ board_col_since = width; }
+void SESSION::set_col_write( const int width ){ board_col_write = width; }
+void SESSION::set_col_speed( const int width ){ board_col_speed = width; }
 
 
 // 現在開いているarticle のurl
@@ -1072,22 +892,22 @@ const std::string SESSION::get_article_current_url()
 
 
 // 埋め込みimage使用
-bool SESSION::get_embedded_img(){ return embedded_img; }
-void SESSION::set_embedded_img( bool set ){ embedded_img = set; }
+const bool SESSION::get_embedded_img(){ return embedded_img; }
+void SESSION::set_embedded_img( const bool set ){ embedded_img = set; }
 
 
 // 埋め込みmessageを使用
-bool SESSION::get_embedded_mes(){ return embedded_mes; }
-void SESSION::set_embedded_mes( bool set ){ embedded_mes = set; }
+const bool SESSION::get_embedded_mes(){ return embedded_mes; }
+void SESSION::set_embedded_mes( const bool set ){ embedded_mes = set; }
 
 // 書き込み後にmessageを閉じる
-bool SESSION::get_close_mes(){ return close_mes; }
-void SESSION::set_close_mes( bool set ){ close_mes = set; }
+const bool SESSION::get_close_mes(){ return close_mes; }
+void SESSION::set_close_mes( const bool set ){ close_mes = set; }
 
 
-// 最後にdatを保存したディレクトリ
-const std::string& SESSION::dir_dat_save(){ return img_dir_dat_save; }
-void SESSION::set_dir_dat_save( const std::string& dir ){ img_dir_dat_save = dir; }
+// 最後にdatを読み書きしたディレクトリ
+const std::string& SESSION::get_dir_dat(){ return dir_dat; }
+void SESSION::set_dir_dat( const std::string& dir ){ dir_dat = dir; }
 
 // 最後に画像を保存したディレクトリ
 const std::string& SESSION::dir_img_save(){ return img_dir_img_save; }
@@ -1100,12 +920,12 @@ void SESSION::set_dir_draft( const std::string& dir ){ dir_draft = dir; }
 
 // ポップアップメニュー表示中
 const bool SESSION::is_popupmenu_shown(){ return popupmenu_shown; }
-void SESSION::set_popupmenu_shown( bool shown ){ popupmenu_shown = shown; }
+void SESSION::set_popupmenu_shown( const bool shown ){ popupmenu_shown = shown; }
 
 
 // JD終了時に削除するスレのリスト
 // 実況などしたスレは削除する。 Core::~Core()を参照
-std::vector< std::string >& SESSION::get_delete_list()
+const std::vector< std::string >& SESSION::get_delete_list()
 {
     return delete_list;
 }
