@@ -8,6 +8,7 @@
 #include "view.h"
 #include "dragnote.h"
 #include "msgdiag.h"
+#include "tabswitchmenu.h"
 
 #include "dbtree/interface.h"
 
@@ -32,6 +33,16 @@ enum
 };
 
 
+// open_view で使うモード
+enum
+{
+    OPEN_MODE_AUTO = 1,
+    OPEN_MODE_NOSWITCH = 2,
+    OPEN_MODE_LOCK = 4,
+    OPEN_MODE_OFFLINE = 8
+};
+
+
 using namespace SKELETON;
 
 
@@ -40,6 +51,7 @@ Admin::Admin( const std::string& url )
       m_win( NULL ),
       m_notebook( NULL ),
       m_focus( false ),
+      m_tabswitchmenu( NULL ),
       m_use_viewhistory( false )
 {
     m_notebook = new DragableNoteBook();
@@ -47,11 +59,14 @@ Admin::Admin( const std::string& url )
     m_notebook->signal_switch_page().connect( sigc::mem_fun( *this, &Admin::slot_switch_page ) );
     m_notebook->set_scrollable( true );
 
-    m_notebook->sig_tab_click().connect( sigc::mem_fun( *this, &Admin::slot_tab_click ) );
+    m_notebook->sig_tab_clicked().connect( sigc::mem_fun( *this, &Admin::slot_tab_clicked ) );
+    m_notebook->sig_tab_scrolled().connect( sigc::mem_fun( *this, &Admin::slot_tab_scrolled ) );
     m_notebook->sig_tab_close().connect( sigc::mem_fun( *this, &Admin::slot_tab_close ) );
     m_notebook->sig_tab_reload().connect( sigc::mem_fun( *this, &Admin::slot_tab_reload ) );
     m_notebook->sig_tab_menu().connect( sigc::mem_fun( *this, &Admin::slot_tab_menu ) );
 
+    m_notebook->get_tabswitch_button().signal_clicked().connect( sigc::mem_fun(*this, &Admin::slot_show_tabswitchmenu ) );
+
     // D&D
     m_notebook->sig_drag_data_get().connect( sigc::mem_fun(*this, &Admin::slot_drag_data_get ) );
 
@@ -90,13 +105,14 @@ Admin::~Admin()
     delete_jdwin();
 
     if( m_notebook ) delete m_notebook;
+    if( m_tabswitchmenu ) delete m_tabswitchmenu;
 }
 
 
 //
 // メニューのセットアップ
 //
-void Admin::setup_menu( const bool enable_checkupdate )
+void Admin::setup_menu()
 {
     // 右クリックメニュー
     m_action_group = Gtk::ActionGroup::create();
@@ -156,16 +172,10 @@ void Admin::setup_menu( const bool enable_checkupdate )
     "<separator/>"
 
     "<menu action='Reload_Tab_Menu'>"
-    "<menuitem action='ReloadAll'/>";
+    "<menuitem action='ReloadAll'/>"
 
-    if( enable_checkupdate ){
-
-        str_ui += 
-        "<menuitem action='CheckUpdateAll'/>"
-        "<menuitem action='CheckUpdateReloadAll'/>";
-    }
-
-    str_ui +=
+    "<menuitem action='CheckUpdateAll'/>"
+    "<menuitem action='CheckUpdateReloadAll'/>"
 
     "<separator/>"
     "<menuitem action='CancelReloadAll'/>"
@@ -194,7 +204,7 @@ void Admin::setup_menu( const bool enable_checkupdate )
     // 移動サブメニュー作成と登録
     for( int i = 0; i < MAX_TABS; ++i ){
         item = Gtk::manage( new Gtk::MenuItem( "dummy" ) );
-        item->signal_activate().connect( sigc::bind< int >( sigc::mem_fun( *this, &Admin::set_current_page ), i ) );
+        item->signal_activate().connect( sigc::bind< int >( sigc::mem_fun( *this, &Admin::set_current_page_focus ), i ) );
 
         m_vec_movemenu_items.push_back( item );
         m_vec_movemenu_append.push_back( false );
@@ -219,11 +229,11 @@ void Admin::setup_menu( const bool enable_checkupdate )
     // 先頭、最後に移動
     item = Gtk::manage( new Gtk::MenuItem( "先頭のタブに移動(_H)", true ) );
     m_move_menu->append( *item );
-    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_head ) );
+    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_head_focus ) );
 
     item = Gtk::manage( new Gtk::MenuItem( "最後のタブに移動(_T)", true ) );
     m_move_menu->append( *item );
-    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_tail ) );
+    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_tail_focus ) );
 
     m_move_menu->append( *Gtk::manage( new Gtk::SeparatorMenuItem() ) );
 
@@ -312,11 +322,11 @@ int Admin::get_tab_nums()
 //
 // 含まれているページのURLのリスト取得
 //
-std::list<std::string> Admin::get_URLs()
+const std::list<std::string> Admin::get_URLs()
 {
     std::list<std::string> urls;
     
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
@@ -487,6 +497,9 @@ void Admin::exec_command()
     else if( command.command == "tab_right" ){
         tab_right();
     }
+    else if( command.command == "tab_num" ){
+        tab_num( command.arg1 );
+    }
     else if( command.command == "tab_head" ){
         tab_head();
     }
@@ -837,31 +850,64 @@ void Admin::update_status( View* view, const bool force )
 //
 // ビューを開く
 //
-// command.arg1: "true" なら新しいtabを開く, "right" ならアクティブなtabの右に、"left"なら左に開く
-// command.arg2: "true" なら既にurlを開いているかチェックしない
+// command.arg1: 開く位置
+//
+// "false" ならアクティブなタブを置き換える
+// "true" なら一番右側に新しいタブを開く
+// "right" ならアクティブなタブの右に開く
+// "left" ならアクティブな左に開く
+// "page数字" なら指定した位置にタブで開く
+//
+// command.arg2: "true" なら既に command.url を開いているかチェックしない
+//
 // command.arg3: モード
-//   arg3 == "auto"なら表示されていればリロードせずに切替え、されていなければ新しいタブで開いてロード(スレ番号ジャンプなどで使用)
-//   arg3 == "noswitch"ならタブを切り替えない(連続して開くときに使用)
-//   arg3 == "lock" なら開いてロックする
+//
+// "auto"なら表示されていればリロードせずに切替える
+// されていなければarg1で指定した場所に新しいタブで開いてロード
+// スレ番号ジャンプなどで使用する
+//
+// "noswitch"ならタブを切り替えない(連続して開くときに使用)
+//
+// "lock" なら開いてからロックする
+//
+// "offline" なら オフラインで開く
+//
 //
 // その他のargは各ビュー別の設定
 //
 void Admin::open_view( const COMMAND_ARGS& command )
 {
 #ifdef _DEBUG
-    std::cout << "Admin::open_view : " << command.url << std::endl;
+    std::cout << "Admin::open_view : " << command.url << std::endl
+              << "arg1 = " << command.arg1 << std::endl
+              << "arg2 = " << command.arg2 << std::endl 
+              << "arg3 = " << command.arg3 << std::endl;   
 #endif
+
     SKELETON::View* view;
     SKELETON::View* current_view = get_current_view();
 
+    const bool online = SESSION::is_online();
+    const bool nocheck_opened = ( command.arg2 == "true" );
+    int mode = 0;
+    if( ! command.arg3.empty() ){
+
+        if( command.arg3.find( "auto" ) != std::string::npos ) mode |= OPEN_MODE_AUTO;
+        if( command.arg3.find( "noswitch" ) != std::string::npos ) mode |= OPEN_MODE_NOSWITCH;
+        if( command.arg3.find( "lock" ) != std::string::npos ) mode |= OPEN_MODE_LOCK;
+        if( command.arg3.find( "offline" ) != std::string::npos ) mode |= OPEN_MODE_OFFLINE;
+    }
+
     if( current_view ) current_view->focus_out();
 
     // urlを既に開いていたら表示してリロード
-    if( ! ( command.arg2 == "true" ) ){
+    if( ! nocheck_opened ){
+
         view = get_view( command.url );
         if( view ){
 
-            if( ! ( command.arg3 == "noswitch" ) ){
+            // タブの切り替え
+            if( ! ( mode & OPEN_MODE_NOSWITCH ) ){
             
                 int page = m_notebook->page_num( *view );
 #ifdef _DEBUG
@@ -872,12 +918,16 @@ void Admin::open_view( const COMMAND_ARGS& command )
             }
 
             // オートモードは切り替えのみ
-            if( command.arg3 == "auto" ) return;
+            if( mode & OPEN_MODE_AUTO ) return;
 
             // ロック
-            if( command.arg3 == "lock" ) lock( m_notebook->page_num( *view ) );
+            if( mode & OPEN_MODE_LOCK ) lock( m_notebook->page_num( *view ) );
+
+            // オフラインで開く
+            if( mode & OPEN_MODE_OFFLINE ) SESSION::set_online( false );
 
             view->show_view();
+            SESSION::set_online( online );
 
             return;
         }
@@ -886,11 +936,11 @@ void Admin::open_view( const COMMAND_ARGS& command )
     view = create_view( command );
     if( !view ) return;
 
-    int page = m_notebook->get_current_page();
-    bool open_tab = (  page == -1
-                       || command.arg1 == "true" || command.arg1 == "right" || command.arg1 == "left"
-                       || command.arg3 == "auto" // オートモードの時もタブで開く
-                       || is_locked( page )
+    const int page = m_notebook->get_current_page();
+    const bool open_tab = (  page == -1
+                             || ( ! command.arg1.empty() && command.arg1 != "false" )
+                             || ( mode & OPEN_MODE_AUTO ) // オートモードの時もタブで開く
+                             || is_locked( page )
         );
 
     // ツールバー表示
@@ -899,14 +949,26 @@ void Admin::open_view( const COMMAND_ARGS& command )
     // タブで表示
     if( open_tab ){
 
-#ifdef _DEBUG
-        std::cout << "append page\n";
-#endif
+        int openpage = -1;
+
         // 現在のページの右に表示
-        if( page != -1 && command.arg1 == "right" ) m_notebook->insert_page( command.url, *view, page+1 );
+        if( command.arg1 == "right" ) openpage = page +1;
 
         // 現在のページの左に表示
-        else if( page != -1 && command.arg1 == "left" ) m_notebook->insert_page( command.url, *view, page );
+        else if( command.arg1 == "left" ) openpage = page;
+
+        // 指定した位置に表示
+        else if( command.arg1.find( "page" ) == 0 ) openpage = atoi( command.arg1.c_str() + 4 );
+
+        // ロックされていたら右に表示
+        else if( command.arg1 != "true" && page != -1 && is_locked( page ) ) openpage = page +1;
+
+#ifdef _DEBUG
+        std::cout << "append page = " << openpage << std::endl;
+#endif
+
+
+        if( page != -1 ) m_notebook->insert_page( command.url, *view, openpage );
 
         // 最後に表示
         else m_notebook->append_page( command.url, *view );
@@ -925,6 +987,7 @@ void Admin::open_view( const COMMAND_ARGS& command )
 
     // 開いてるviewを消してその場所に表示
     else{
+
 #ifdef _DEBUG
         std::cout << "replace page\n";
 #endif
@@ -944,18 +1007,24 @@ void Admin::open_view( const COMMAND_ARGS& command )
 
     m_notebook->show_all();
     view->show();
+
+    // オフラインで開く
+    if( mode & OPEN_MODE_OFFLINE ) SESSION::set_online( false );
+
     view->show_view();
+    SESSION::set_online( online );
 
     // ツールバーの情報更新
     m_notebook->set_current_toolbar( view->get_id_toolbar(), view );
 
-    if( ! ( command.arg3 == "noswitch" ) ){
+    // タブの切り替え
+    if( ! ( mode & OPEN_MODE_NOSWITCH ) ){
         switch_admin();
         set_current_page( m_notebook->page_num( *view ) );
     }
 
     // ロック
-    if( command.arg3 == "lock" ) lock( m_notebook->page_num( *view ) );
+    if( mode & OPEN_MODE_LOCK ) lock( m_notebook->page_num( *view ) );
 }
 
 
@@ -1040,6 +1109,26 @@ void Admin::tab_right()
 }
 
 
+//
+// タブ位置(1-9)で移動
+//
+void Admin::tab_num( const std::string& str_num )
+{
+    if( str_num.empty() ) return;
+
+    const int num = strtol( str_num.c_str(), NULL, 10 );
+
+    // Firefoxの動作に合わせた
+    // 0 → 無視
+    // 8以下で存在する数より多い → 無視
+    // 9(存在しない) → 最後のタブ
+    if ( num < 1 || num > 9 ||
+         ( num < 9 && num > get_tab_nums() ) ) return;
+
+    // 9は存在しなくてもそのまま渡してしまう
+    set_current_page( num - 1 );
+}
+
 
 //
 // タブ先頭移動
@@ -1053,6 +1142,15 @@ void Admin::tab_head()
 }
 
 
+//
+// フォーカスしてタブ先頭移動
+//
+void Admin::tab_head_focus()
+{
+    if( ! m_focus ) switch_admin();
+    tab_head();
+}
+
 
 //
 // タブ最後に移動
@@ -1066,6 +1164,14 @@ void Admin::tab_tail()
 }
 
 
+//
+// タブ最後に移動
+//
+void Admin::tab_tail_focus()
+{
+    if( ! m_focus ) switch_admin();
+    tab_tail();
+}
 
 
 //
@@ -1502,25 +1608,28 @@ void Admin::toggle_icon( const std::string& url )
         // オートリロードモードでロード待ち
         else if( view->get_autoreload_mode() != AUTORELOAD_NOT ) iconname = "loading_stop";
 
-        // 更新可能
+        // 古い
+        else if( view->is_old() ) iconname = "old";
+
+        // 更新チェックして更新可能 ( 更新はしていない )
         else if( view->is_check_update() ) iconname = "update";
 
-        // 更新済み
+        // 更新済み ( HTTP_OK 又は HTTP_PARTIAL_CONTENT )
         else if( view->is_updated() ){
 
             // タブがアクティブの時は通常アイコンを表示
             if( get_notebook()->page_num( *view ) == get_notebook()->get_current_page() ) iconname = "default";
+
             else iconname = "updated";
         }
 
-        // 古い
-        else if( view->is_old() ) iconname = "old";
-
 #ifdef _DEBUG
         std::cout << "name = " << iconname << std::endl;
 #endif
         int id = view->get_icon( iconname );
         get_notebook()->set_tabicon( iconname, get_notebook()->page_num( *view ), id );
+
+        if( m_tabswitchmenu ) m_tabswitchmenu->update_icons();
     }
 }
 
@@ -1641,12 +1750,21 @@ View* Admin::get_current_view()
 //
 // 指定したページに表示切替え
 //
-void Admin::set_current_page( int page )
+void Admin::set_current_page( const int page )
 {
     m_notebook->set_current_page( page );
 }
 
 
+//
+// フォーカスしてから指定したページに表示切替え
+//
+void Admin::set_current_page_focus( const int page )
+{
+    if( ! m_focus ) switch_admin();
+    m_notebook->set_current_page( page );
+}
+
 
 //
 // 現在表示されているページ番号
@@ -1704,22 +1822,33 @@ void Admin::slot_switch_page( GtkNotebookPage*, guint page )
 
 
 //
-// タブをクリック
+// タブをクリックした
 //
-void Admin::slot_tab_click( int page )
+void Admin::slot_tab_clicked( const int page )
 {
 #ifdef _DEBUG
-    std::cout << "Admin::slot_tab_click " << page << std::endl;
+    std::cout << "Admin::slot_tab_clicked " << page << std::endl;
 #endif
 
-    set_current_page( page );
+    if( ! m_focus ) switch_admin();
+}
+
+
+// タブの上でホイールを回した
+void Admin::slot_tab_scrolled( GdkEventScroll* event )
+{
+#ifdef _DEBUG
+    std::cout << "Admin::slot_tab_scrolled\n";
+#endif
+
+    if( ! m_focus ) switch_admin();
 }
 
 
 //
 // タブを閉じる
 //
-void Admin::slot_tab_close( int page )
+void Admin::slot_tab_close( const int page )
 {
 #ifdef _DEBUG
     std::cout << "Admin::slot_tab_close " << page << std::endl;
@@ -1734,7 +1863,7 @@ void Admin::slot_tab_close( int page )
 //
 // タブ再読み込み
 //
-void Admin::slot_tab_reload( int page )
+void Admin::slot_tab_reload( const int page )
 {
 #ifdef _DEBUG
     std::cout << "Admin::slot_tab_reload " << page << std::endl;
@@ -1834,6 +1963,42 @@ void Admin::slot_tab_menu( int page, int x, int y )
 }
 
 
+// タブ切り替えメニュー表示
+void Admin::slot_show_tabswitchmenu()
+{
+#ifdef _DEBUG
+    std::cout << "Admin::slot_show_tabswitchmenu\n";
+#endif
+
+    if( m_tabswitchmenu ) delete m_tabswitchmenu;
+
+    m_tabswitchmenu = new  SKELETON::TabSwitchMenu( m_notebook, this );
+    m_tabswitchmenu->popup( Gtk::Menu::SlotPositionCalc( sigc::mem_fun( *this, &Admin::slot_popup_pos ) ),
+                            0, gtk_get_current_event_time() );
+}
+
+
+// タブ切り替えメニューの位置決め
+void Admin::slot_popup_pos( int& x, int& y, bool& push_in )
+{
+    if( ! m_tabswitchmenu ) return;
+    if( ! m_notebook ) return;
+
+    const int mrg = 16;
+
+    m_notebook->get_tabswitch_button().get_pointer( x, y );
+
+    int ox, oy;
+    m_notebook->get_tabswitch_button().get_window()->get_origin( ox, oy );
+    const Gdk::Rectangle rect = m_notebook->get_tabswitch_button().get_allocation();
+
+    x += ox + rect.get_x() - mrg;
+    y = oy + rect.get_y() + rect.get_height();
+
+    push_in = false;
+}
+
+
 //
 // 右クリックメニューの閉じる
 //
@@ -1941,9 +2106,9 @@ void Admin::slot_close_all_tabs()
 //
 void Admin::slot_check_update_all_tabs()
 {
-    check_update_all_tabs( m_clicked_page );
+    check_update_all_tabs( m_clicked_page, false );
 
-    CORE::get_checkupdate_manager()->run( false );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -1952,9 +2117,9 @@ void Admin::slot_check_update_all_tabs()
 //
 void Admin::slot_check_update_reload_all_tabs()
 {
-    check_update_all_tabs( m_clicked_page );
+    check_update_all_tabs( m_clicked_page, true );
 
-    CORE::get_checkupdate_manager()->run( true );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -1963,7 +2128,7 @@ void Admin::slot_check_update_reload_all_tabs()
 //
 // この後で CORE::get_checkupdate_manager()->run() すること
 //
-void Admin::check_update_all_tabs( const int from_page )
+void Admin::check_update_all_tabs( const int from_page, const bool open )
 {
 #ifdef _DEBUG
     std::cout << "Admin::check_update_all_tabs from = " << from_page << std::endl;
@@ -1976,13 +2141,13 @@ void Admin::check_update_all_tabs( const int from_page )
     // クリックしたタブから右側
     for( int i = from_page ; i < pages; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url() );
+        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url(), open );
     }
 
     // クリックしたタブから左側
     for( int i = 0 ; i < from_page; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url() );
+        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url(), open );
     }
 }
 
@@ -2123,6 +2288,14 @@ const bool Admin::is_locked( const int page )
     return false;
 }
 
+const bool Admin::is_locked( const std::string& url )
+{
+    SKELETON::View* view = get_view( url );
+    if( view ) return view->is_locked();
+
+    return false;
+}
+
 void Admin::lock( const int page )
 {
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
@@ -2164,7 +2337,7 @@ void Admin::back_clicked_viewhistory( const int count )
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
     if( ! view ) return;
     
-    m_notebook->set_current_page( m_clicked_page );
+    set_current_page( m_clicked_page );
     back_forward_viewhistory( view->get_url(), true, count );
 }
 
@@ -2185,7 +2358,7 @@ void Admin::forward_clicked_viewhistory( const int count )
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
     if( ! view ) return;
 
-    m_notebook->set_current_page( m_clicked_page );
+    set_current_page( m_clicked_page );
     back_forward_viewhistory( view->get_url(), false, count );
 }
 
