@@ -22,6 +22,7 @@ DragableNoteBook::DragableNoteBook()
     , m_notebook_tab( this )
     , m_notebook_toolbar( this )
     , m_notebook_view( this )
+    , m_bt_tabswitch( this )
     , m_page( -1 )
     , m_dragging_tab( false )
     , m_dragable( false )
@@ -38,7 +39,13 @@ DragableNoteBook::DragableNoteBook()
 
     m_notebook_tab.sig_tab_drag_motion().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_drag_motion ) );
 
-    pack_start( m_notebook_tab, Gtk::PACK_SHRINK );
+    m_notebook_tab.sig_scroll_event().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_scroll_event ) );
+
+    m_hbox_tab.pack_start( m_notebook_tab );
+    m_hbox_tab.pack_start( m_bt_tabswitch, Gtk::PACK_SHRINK );
+    m_tooltip_tabswitch.set_tip( m_bt_tabswitch, "タブの一覧表示" );
+
+    pack_start( m_hbox_tab, Gtk::PACK_SHRINK );
     pack_start( m_notebook_toolbar, Gtk::PACK_SHRINK );
     pack_start( m_notebook_view );
     m_show_tabs = true;
@@ -83,7 +90,8 @@ bool DragableNoteBook::on_expose_event( GdkEventExpose* event )
 {
     const bool ret =  Gtk::VBox::on_expose_event( event );
 
-    if( m_notebook_toolbar.get_parent() == this ){
+    // ツールバー再描画
+   if( m_notebook_toolbar.get_parent() == this ){
 
         const int min_toolbar_height = 4;
         const Alloc_NoteBook alloc = get_alloc_notebook();
@@ -113,12 +121,15 @@ bool DragableNoteBook::on_expose_event( GdkEventExpose* event )
                       << " w_t = " << event_toolbar.area.width
                       << " h_t = " << event_toolbar.area.height
                       << std::endl;
-#endif        
-            propagate_expose( m_notebook_toolbar, &event_toolbar );
+#endif
+            if( event_toolbar.area.height ){
+ 
+                propagate_expose( m_notebook_toolbar, &event_toolbar );
 
-            // (注意) Auroraなどテーマによってはクリップ領域( event->area )を無視するものがあり
-            // ビューのスクロールバーが消えてしまう時があるので明示的に再描画する
-            m_notebook_view.redraw_scrollbar();
+                // (注意) Auroraなどテーマによってはクリップ領域( event->area )を無視するものがあり
+                // ビューのスクロールバーが消えてしまう時があるので明示的に再描画する
+                m_notebook_view.redraw_scrollbar();
+            }
         }
     }
     return ret;
@@ -132,26 +143,34 @@ bool DragableNoteBook::on_expose_event( GdkEventExpose* event )
 const Alloc_NoteBook DragableNoteBook::get_alloc_notebook()
 {
     Alloc_NoteBook alloc;
+
+    m_notebook_tab.get_alloc_tab( alloc );
+
     alloc.y_tabbar = m_notebook_tab.get_allocation().get_y();
     alloc.height_tabbar = m_notebook_tab.get_allocation().get_height();
 
     alloc.y_toolbar = m_notebook_toolbar.get_allocation().get_y();
     alloc.height_toolbar = m_notebook_toolbar.get_allocation().get_height();
 
-    alloc.height_view = m_notebook_view.get_allocation().get_height();
-
-    m_notebook_tab.get_alloc_tab( alloc.x_tab, alloc.width_tab, alloc.height_tab );
+    const int offset_tabbar = ( get_show_tabs() ? alloc.height_tabbar - alloc.height_tab : 0 );
+    alloc.x_box = m_notebook_view.get_allocation().get_x();
+    alloc.y_box = m_notebook_view.get_allocation().get_y() - alloc.height_toolbar - offset_tabbar;
+    alloc.width_box =m_notebook_view.get_allocation().get_width();
+    alloc.height_box = offset_tabbar + alloc.height_toolbar + m_notebook_view.get_allocation().get_height();
 
 #ifdef _DEBUG
     std::cout << "DragableNoteBook::get_alloc_notebook"
+              << " x_tab = " << alloc.x_tab
+              << " w_tab = " << alloc.width_tab
+              << " h_tab = " << alloc.height_tab
               << " y_tabbar = " << alloc.y_tabbar
               << " h_tabbar = " << alloc.height_tabbar
               << " y_toolbar = " << alloc.y_toolbar
               << " h_toolbar = " << alloc.height_toolbar
-              << " h_view = " << alloc.height_view
-              << " x_tab = " << alloc.x_tab
-              << " w_tab = " << alloc.width_tab
-              << " h_tab = " << alloc.height_tab
+              << " x_box = " << alloc.x_box
+              << " y_box = " << alloc.y_box
+              << " w_box = " << alloc.width_box
+              << " h_box = " << alloc.height_box
               << std::endl;
 #endif
 
@@ -159,6 +178,54 @@ const Alloc_NoteBook DragableNoteBook::get_alloc_notebook()
 }
 
 
+//
+// 枠描画
+//
+// gtknotebook.c( Revision 19593, Sat Feb 16 04:09:15 2008 UTC ) からのハック。環境やバージョンによっては問題が出るかもしれないので注意
+//
+void DragableNoteBook::draw_box( Gtk::Widget* widget, GdkEventExpose* event )
+{
+    const Glib::RefPtr<Gdk::Window> win = widget->get_window();
+    const Gdk::Rectangle rect( &(event->area) );
+    const Alloc_NoteBook alloc = get_alloc_notebook();
+
+    if( alloc.height_box > 0 ){
+
+        if( get_show_tabs() ){
+
+            widget->get_style()->paint_box_gap( win,
+                                                Gtk::STATE_NORMAL,
+                                                Gtk::SHADOW_OUT,
+                                                rect,
+                                                *widget,
+                                                "notebook",
+                                                alloc.x_box,
+                                                alloc.y_box,
+                                                alloc.width_box,
+                                                alloc.height_box,
+                                                Gtk::POS_TOP,
+                                                alloc.x_tab,
+                                                alloc.width_tab
+                );
+        }
+        else{
+
+            widget->get_style()->paint_box( win,
+                                            Gtk::STATE_NORMAL,
+                                            Gtk::SHADOW_OUT,
+                                            rect,
+                                            *widget,
+                                            "notebook",
+                                            alloc.x_box,
+                                            alloc.y_box,
+                                            alloc.width_box,
+                                            alloc.height_box
+                );
+        }
+    }
+}
+
+
 void DragableNoteBook::set_show_tabs( bool show_tabs )
 {
 #ifdef _DEBUG
@@ -167,7 +234,7 @@ void DragableNoteBook::set_show_tabs( bool show_tabs )
 
     if( m_show_tabs ){
 
-        remove( m_notebook_tab );
+        remove( m_hbox_tab );
 
         m_show_tabs = false;
     }
@@ -176,7 +243,7 @@ void DragableNoteBook::set_show_tabs( bool show_tabs )
         remove( m_notebook_toolbar );
         remove( m_notebook_view );
 
-        pack_start( m_notebook_tab, Gtk::PACK_SHRINK );
+        pack_start( m_hbox_tab, Gtk::PACK_SHRINK );
         pack_start( m_notebook_toolbar, Gtk::PACK_SHRINK );
         pack_start( m_notebook_view );
 
@@ -235,6 +302,8 @@ int DragableNoteBook::append_page( const std::string& url, Gtk::Widget& child )
 {
     m_notebook_view.append_page( child );
 
+    m_bt_tabswitch.show_button();
+
     SKELETON::TabLabel* tablabel = create_tablabel( url );
     return m_notebook_tab.append_tab( *tablabel );
 }
@@ -244,6 +313,8 @@ int DragableNoteBook::insert_page( const std::string& url, Gtk::Widget& child, i
 {
     m_notebook_view.insert_page( child, page );
 
+    m_bt_tabswitch.show_button();
+
     SKELETON::TabLabel* tablabel = create_tablabel( url );
     return m_notebook_tab.insert_tab( *tablabel, page );
 }
@@ -252,7 +323,7 @@ int DragableNoteBook::insert_page( const std::string& url, Gtk::Widget& child, i
 //
 // タブの文字列取得
 //
-const std::string DragableNoteBook::get_tab_fulltext( int page )
+const std::string DragableNoteBook::get_tab_fulltext( const int page )
 {
     return m_notebook_tab.get_tab_fulltext( page );
 }
@@ -262,7 +333,7 @@ const std::string DragableNoteBook::get_tab_fulltext( int page )
 //
 // タブに文字列をセットとタブ幅調整
 //
-void DragableNoteBook::set_tab_fulltext( const std::string& str, int page )
+void DragableNoteBook::set_tab_fulltext( const std::string& str, const int page )
 {
     m_notebook_tab.set_tab_fulltext( str, page );
 }
@@ -282,6 +353,8 @@ void DragableNoteBook::remove_page( int page )
     if( tablabel ) delete tablabel;
 
     m_tooltip.hide_tooltip();
+
+    if( ! get_n_pages() ) m_bt_tabswitch.hide_button();
 }
 
 
@@ -321,7 +394,6 @@ void DragableNoteBook::show_toolbar()
 // ツールバー全体を非表示
 //
 // タブに全てのビューが無くなったら admin から呼び出される
-// ToolBar::hide_toolbar() の方は検索ツールバーは表示したまま
 //
 void DragableNoteBook::hide_toolbar()
 {
@@ -369,7 +441,10 @@ void DragableNoteBook::set_current_toolbar( int page_num, SKELETON::View* view )
 
     // ツールバーのラベルなどの情報を更新
     SKELETON::ToolBar* toolbar = get_toolbar( page_num );
-    if( toolbar ) toolbar->set_view( view );
+    if( toolbar ){
+        toolbar->set_view( view );
+        toolbar->show_toolbar();
+    }
 }
 
 
@@ -413,6 +488,18 @@ void DragableNoteBook::update_toolbar_button()
 }
 
 
+//
+// タブのアイコンを取得する
+//
+const int DragableNoteBook::get_tabicon( const int page )
+{
+    SKELETON::TabLabel* tablabel = m_notebook_tab.get_tablabel( page );
+    if( tablabel ) return tablabel->get_id_icon();
+
+    return ICON::NONE;
+}
+
+
 //
 // タブにアイコンをセットする
 //
@@ -502,7 +589,11 @@ bool DragableNoteBook::slot_button_press_event( GdkEventButton* event )
     if( m_page >= 0 && m_page < get_n_pages() ){
 
         // ページ切替え
-        if( m_control.button_alloted( event, CONTROL::ClickButton ) ) m_sig_tab_click.emit( m_page );
+        if( m_control.button_alloted( event, CONTROL::ClickButton ) ){
+
+            set_current_page( m_page );
+            m_sig_tab_clicked.emit( m_page );
+        }
 
         return true;
     }
@@ -597,6 +688,32 @@ void DragableNoteBook::slot_leave_event()
 }
 
 
+// notebook_tab の上でホイールを回した
+bool DragableNoteBook::slot_scroll_event( GdkEventScroll* event )
+{
+#ifdef _DEBUG
+    std::cout << "DragableNoteBook::slot_scroll_event direction = " << event->direction << " page = " << get_current_page() << std::endl;
+#endif
+
+    bool ret = false;
+
+    // タブの循環
+    if( event->direction == GDK_SCROLL_UP && get_current_page() == 0 ){
+        set_current_page( get_n_pages() -1 );
+        ret = true;
+    }
+    else if( event->direction == GDK_SCROLL_DOWN && get_current_page() == get_n_pages() -1 ){
+        set_current_page( 0 );
+        ret = true;
+    }
+
+    m_sig_tab_scrolled.emit( event );
+
+    return ret;
+}
+
+
+
 //
 // タブのドラッグを開始
 //
@@ -627,7 +744,7 @@ void DragableNoteBook::slot_drag_motion( const int page, const int tab_x, const
     if( page < 0 || page == m_page ){
         if( m_down_arrow ) m_down_arrow->hide();
     }
-    else{
+    else if( m_dragging_tab ){
 
         if( ! m_down_arrow ) m_down_arrow = new SKELETON::IconPopup( ICON::DOWN );
         m_down_arrow->show();
@@ -692,5 +809,7 @@ void DragableNoteBook::slot_drag_end()
 
     m_dragging_tab = false;
 
+    if( m_down_arrow ) m_down_arrow->hide();
+
     CORE::DND_End();
 }
